package org.eclipse.soda.dk.testagent;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintStream;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.testagent.service.TestSynchronizationService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class ConsoleSynchronization implements TestSynchronizationService {
	/**
	 * Print event with the specified error, message and detail parameters.
	 * @param error	The error (<code>boolean</code>) parameter.
	 * @param message	The message (<code>String</code>) parameter.
	 * @param detail	The detail (<code>String</code>) parameter.
	 */
	protected synchronized void printEvent(final boolean error, final String message, final String detail) {
		PrintStream out = error ? System.err : System.out;
		String timestamp = Nls.formatTimestamp(System.currentTimeMillis());
		out.print(timestamp);
		out.print(' ');
		out.println(message);
		if (detail != null) {
			out.println(detail);
		}
		out.flush();
	}

	/**
	 * Request confirmation with the specified prompt and test name parameters and return the boolean result.
	 * @param prompt	The prompt (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @return	Results of the request confirmation (<code>boolean</code>) value.
	 * @throws InterruptedException Interrupted Exception.
	 */
	public synchronized boolean requestConfirmation(final String prompt, final String testName) throws InterruptedException {
		System.out.println();
		Object[] parms1 = { testName };
		System.out.println(Nls.format(TestAgent.DefaultResourceBundle.getString(Integer.toString(TestAgent.PROMPT)), parms1));
		BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
		String line = null;
		boolean confirm = false;
		boolean cancel;
		try {
			do {
				Object[] parms2 = { prompt };
				System.out.print(Nls.format(TestAgent.DefaultResourceBundle.getString(Integer.toString(TestAgent.OK_CANCEL_PROMPT)), parms2));
				System.out.flush();
				line = reader.readLine();
				confirm = TestAgent.DefaultResourceBundle.getString(Integer.toString(TestAgent.YES_CHAR)).equalsIgnoreCase(line);
				cancel = TestAgent.DefaultResourceBundle.getString(Integer.toString(TestAgent.NO_CHAR)).equalsIgnoreCase(line);
				if (!confirm && !cancel) {
					System.out.println(TestAgent.DefaultResourceBundle.getString(Integer.toString(TestAgent.INVALID_REPLY)));
				}
			} while (!confirm && !cancel);
		} catch (final IOException e) {
			e.printStackTrace();
		}
		System.out.println();
		return confirm;
	}
}
