package org.eclipse.soda.dk.testagent.framework;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Dictionary;
import junit.framework.TestSuite;
import org.eclipse.soda.dk.core.service.ConfigurationService;
import org.eclipse.soda.dk.testagent.TestAgent;
import org.eclipse.soda.dk.testagent.service.TestSynchronizationService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class ConfiguredTestSuite extends TestSuite {
	/**
	 * Define the context (TestContext) field.
	 */
	private TestContext context = TestAgent.getTestContext();

	/**
	 * Constructs an empty TestSuite.
	 * @see #ConfiguredTestSuite(Class,String)
	 * @see #ConfiguredTestSuite(Class)
	 * @see #ConfiguredTestSuite(String)
	 */
	public ConfiguredTestSuite() {
		super();
	}

	/**
	 * Constructs a TestSuite from the given class with the given name.
	 * @see TestSuite#TestSuite(Class)
	 * @param theClass	The the class (<code>Class</code>) parameter.
	 * @param name	The name (<code>String</code>) parameter.
	 * @see #ConfiguredTestSuite()
	 * @see #ConfiguredTestSuite(Class)
	 * @see #ConfiguredTestSuite(String)
	 */
	public ConfiguredTestSuite(final Class theClass, final String name) {
		super(theClass, name);
	}

	/**
	 * Constructs a TestSuite from the given class. Adds all the methods
	 * starting with "test" as test cases to the suite.
	 * @param theClass	The the class (<code>Class</code>) parameter.
	 * @see #ConfiguredTestSuite()
	 * @see #ConfiguredTestSuite(Class,String)
	 * @see #ConfiguredTestSuite(String)
	 */
	public ConfiguredTestSuite(final Class theClass) {
		super(theClass);
	}

	/**
	 * Constructs an empty TestSuite.
	 * @param name	The name (<code>String</code>) parameter.
	 * @see #ConfiguredTestSuite()
	 * @see #ConfiguredTestSuite(Class,String)
	 * @see #ConfiguredTestSuite(Class)
	 */
	public ConfiguredTestSuite(final String name) {
		super(name);
	}

	/**
	 * Add test with the specified test class parameter.
	 * @param testClass	The test class (<code>Class</code>) parameter.
	 */
	protected void addTest(final Class testClass) {
		addTest(new SortedTestSuite(testClass));
	}

	/**
	 * Get boolean with the specified key and default boolean parameters and return the boolean result.
	 * @param key	The key (<code>String</code>) parameter.
	 * @param defaultBoolean	The default boolean (<code>boolean</code>) parameter.
	 * @return	Results of the get boolean (<code>boolean</code>) value.
	 */
	public boolean getBoolean(final String key, final boolean defaultBoolean) {
		return getConfigurationService().getBoolean(key, defaultBoolean);
	}

	/**
	 * Gets the configuration service value.
	 * @return the configurationService
	 */
	public ConfigurationService getConfigurationService() {
		return this.context.getConfigurationService();
	}

	/**
	 * Gets the context (TestContext) value.
	 * @return the context
	 */
	public TestContext getContext() {
		return this.context;
	}

	/**
	 * Get float with the specified key and default float parameters and return the float result.
	 * @param key	The key (<code>String</code>) parameter.
	 * @param defaultFloat	The default float (<code>float</code>) parameter.
	 * @return	Results of the get float (<code>float</code>) value.
	 */
	public float getFloat(final String key, final float defaultFloat) {
		return getConfigurationService().getFloat(key, defaultFloat);
	}

	/**
	 * Get int with the specified key and default int parameters and return the int result.
	 * @param key	The key (<code>String</code>) parameter.
	 * @param defaultInt	The default int (<code>int</code>) parameter.
	 * @return	Results of the get int (<code>int</code>) value.
	 */
	public int getInt(final String key, final int defaultInt) {
		return getConfigurationService().getInt(key, defaultInt);
	}

	/**
	 * Get long with the specified key and default long parameters and return the long result.
	 * @param key	The key (<code>String</code>) parameter.
	 * @param defaultLong	The default long (<code>long</code>) parameter.
	 * @return	Results of the get long (<code>long</code>) value.
	 */
	public long getLong(final String key, final long defaultLong) {
		return getConfigurationService().getLong(key, defaultLong);
	}

	/**
	 * Get object with the specified key and default object parameters and return the Object result.
	 * @param key	The key (<code>String</code>) parameter.
	 * @param defaultObject	The default object (<code>Object</code>) parameter.
	 * @return	Results of the get object (<code>Object</code>) value.
	 */
	public Object getObject(final String key, final Object defaultObject) {
		return getConfigurationService().getObject(key, defaultObject);
	}

	/**
	 * Gets the properties (Dictionary) value.
	 * @return	The properties (<code>Dictionary</code>) value.
	 */
	public Dictionary getProperties() {
		return getConfigurationService().getProperties();
	}

	/**
	 * Get string with the specified key and default string parameters and return the String result.
	 * @param key	The key (<code>String</code>) parameter.
	 * @param defaultString	The default string (<code>String</code>) parameter.
	 * @return	Results of the get string (<code>String</code>) value.
	 */
	public String getString(final String key, final String defaultString) {
		return getConfigurationService().getString(key, defaultString);
	}

	/**
	 * Gets the synchronization service (TestSynchronizationService) value.
	 * @return the syncService
	 */
	public TestSynchronizationService getSynchronizationService() {
		return this.context.getSynchronizationService();
	}
}
