package org.eclipse.soda.dk.testagent.framework;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Dictionary;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.testagent.util.NotificationProbe;
import org.eclipse.soda.dk.testagent.TestAgent;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public abstract class NotificationClientTestCase extends ConfiguredTestCase {
	/**
	 * Define the probe (NotificationProbe) field.
	 */
	private NotificationProbe probe = null;

	/**
	 * No-arg constructor to enable serialization. This method is not intended
	 * to be used by mere mortals without calling setName().
	 * @see #NotificationClientTestCase(String)
	 */
	protected NotificationClientTestCase() {
		super();
	}

	/**
	 * Constructs a test case with the given name.
	 * @param name	The name (<code>String</code>) parameter.
	 * @see #NotificationClientTestCase()
	 */
	protected NotificationClientTestCase(final String name) {
		super(name);
	}

	/**
	 * Broadcast with the specified topic and data parameters.
	 * @param topic	The topic (<code>String</code>) parameter.
	 * @param data	The data (<code>Dictionary</code>) parameter.
	 * @see #broadcast(String,Object,Object)
	 */
	public void broadcast(final String topic, final Dictionary data) {
		getNotificationService().broadcast(topic, data);
	}

	/**
	 * Broadcast with the specified topic, data key and data value parameters.
	 * @param topic	The topic (<code>String</code>) parameter.
	 * @param dataKey	The data key (<code>Object</code>) parameter.
	 * @param dataValue	The data value (<code>Object</code>) parameter.
	 * @see #broadcast(String,Dictionary)
	 */
	public void broadcast(final String topic, final Object dataKey, final Object dataValue) {
		getNotificationService().broadcast(topic, NotificationProbe.toData(dataKey, dataValue));
	}

	/**
	 * Gets the external keys (String[]) value.
	 * @return	The external keys (<code>String[]</code>) value.
	 */
	protected String[] getExternalKeys() {
		return null;
	}

	/**
	 * Gets the notification service value.
	 * @return the notificationService
	 */
	public NotificationService getNotificationService() {
		NotificationService notificationService = getContext().getNotificationService();
		assertNotNull(TestAgent.DefaultResourceBundle.getString(Integer.toString(TestAgent.NOTIFICATION_SEVICE_NOT_AVAILABLE)), notificationService);
		return notificationService;
	}

	/**
	 * Gets the probe (NotificationProbe) value.
	 * @return the probe
	 */
	public NotificationProbe getProbe() {
		return this.probe;
	}

	/**
	 * Register with the specified topic parameter.
	 * @param topic	The topic (<code>String</code>) parameter.
	 * @see #register(String[])
	 */
	public void register(final String topic) {
		getNotificationService().register(topic, this.probe);
	}

	/**
	 * Register with the specified topics parameter.
	 * @param topics	The topics (<code>String[]</code>) parameter.
	 * @see #register(String)
	 */
	public void register(final String[] topics) {
		getNotificationService().register(topics, this.probe);
	}

	/**
	 * Set up.
	 * @throws Exception Exception.
	 */
	protected void setUp() throws Exception {
		super.setUp();
		this.probe = new NotificationProbe();
		String externalKeys[] = getExternalKeys();
		if (externalKeys != null) {
			register(externalKeys);
		}
	}

	/**
	 * Tear down.
	 * @throws Exception Exception.
	 */
	protected void tearDown() throws Exception {
		unregister();
		super.tearDown();
	}

	/**
	 * Unregister.
	 */
	public void unregister() {
		getNotificationService().unregister(this.probe);
	}
}
