package org.eclipse.soda.dk.testagent.framework;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Enumeration;
import java.util.List;
import junit.framework.TestSuite;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class SortedTestSuite extends TestSuite {
	/**
	 * Constructs an empty TestSuite.
	 * @see #SortedTestSuite(Class,String)
	 * @see #SortedTestSuite(Class)
	 * @see #SortedTestSuite(String)
	 */
	public SortedTestSuite() {
		super();
	}

	/**
	 * Constructs a TestSuite from the given class with the given name.
	 * @see TestSuite#TestSuite(Class)
	 * @param theClass	The the class (<code>Class</code>) parameter.
	 * @param name	The name (<code>String</code>) parameter.
	 * @see #SortedTestSuite()
	 * @see #SortedTestSuite(Class)
	 * @see #SortedTestSuite(String)
	 */
	public SortedTestSuite(final Class theClass, final String name) {
		super(theClass, name);
	}

	/**
	 * Constructs a TestSuite from the given class. Adds all the methods
	 * starting with "test" as test cases to the suite.
	 * @param theClass	The the class (<code>Class</code>) parameter.
	 * @see #SortedTestSuite()
	 * @see #SortedTestSuite(Class,String)
	 * @see #SortedTestSuite(String)
	 */
	public SortedTestSuite(final Class theClass) {
		super(theClass);
	}

	/**
	 * Constructs an empty TestSuite.
	 * @param name	The name (<code>String</code>) parameter.
	 * @see #SortedTestSuite()
	 * @see #SortedTestSuite(Class,String)
	 * @see #SortedTestSuite(Class)
	 */
	public SortedTestSuite(final String name) {
		super(name);
	}

	/**
	 * Tests and return the Enumeration result.
	 * @return	Results of the tests (<code>Enumeration</code>) value.
	 */
	public Enumeration tests() {
		Enumeration unsortedTests = super.tests();
		List sortedTests = new ArrayList();
		while (unsortedTests.hasMoreElements()) {
			sortedTests.add(unsortedTests.nextElement());
		}
		Collections.sort(sortedTests, new Comparator() {
			/**
			 * Compare with the specified test1 and test2 parameters and return the int result.
			 * @param test1	The test1 (<code>Object</code>) parameter.
			 * @param test2	The test2 (<code>Object</code>) parameter.
			 * @return	Results of the compare (<code>int</code>) value.
			 */
			public int compare(final Object test1, final Object test2) {
				return test1.toString().compareTo(test2.toString());
			}
		});
		return Collections.enumeration(sortedTests);
	}
}
