package org.eclipse.soda.dk.testagent.framework;

/*************************************************************************
 * Copyright (c) 2006, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Dictionary;
import org.eclipse.soda.dk.core.service.ConfigurationService;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.testagent.service.TestAgentService;
import org.eclipse.soda.dk.testagent.service.TestSynchronizationService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface TestContext {
	/**
	 * Gets the configuration information (Dictionary) value.
	 * @return The configuration information (<code>Dictionary</code>)
	 * value.
	 * @see #getConfigurationInformation(String)
	 */
	public Dictionary getConfigurationInformation();

	/**
	 * Return the property value. The property name (<code>String</code>)
	 * parameter.
	 * @param propertyName	The property name (<code>String</code>) parameter.
	 * @return Results of the get configuration information (<code>Object</code>)
	 * value.
	 * The property name (<code>String</code>) parameter.
	 * @see #getConfigurationInformation()
	 */
	public Object getConfigurationInformation(final String propertyName);

	/**
	 * Gets the configuration service value.
	 * @return The configuration service (<code>ConfigurationService</code>)
	 * value.
	 */
	public ConfigurationService getConfigurationService();

	/**
	 * Gets the notification service value.
	 * @return The notification service (<code>NotificationService</code>)
	 * value.
	 */
	public NotificationService getNotificationService();

	/**
	 * Gets the test synchronization service value.
	 * @return The test synchronization service (<code>TestSynchronizationService</code>)
	 * value.
	 */
	public TestSynchronizationService getSynchronizationService();

	/**
	 * Gets the test agent (TestAgentService) value.
	 * @return	The test agent (<code>TestAgentService</code>) value.
	 */
	public TestAgentService getTestAgent();

	/**
	 * Log the event.
	 * an int defining the severity of the event (should be one of
	 * EscObject.LOG_ERROR, LOG_WARNING, LOG_INFO, or LOG_DEBUG)
	 * a java.lang.String containing a readable description of the
	 * log entry
	 * @param severity	The severity (<code>int</code>) parameter.
	 * @param message	The message (<code>String</code>) parameter.
	 * @see #log(int,String,Throwable)
	 */
	public void log(final int severity, final String message);

	/**
	 * Log the event.
	 * an int defining the severity of the event (should be one of
	 * EscObject.LOG_ERROR, LOG_WARNING, LOG_INFO, or LOG_DEBUG)
	 * a java.lang.String containing a readable description of the
	 * log entry
	 * the java.lang.Throwable which led to the log entry, may be
	 * <code>null</code>
	 * @param severity	The severity (<code>int</code>) parameter.
	 * @param message	The message (<code>String</code>) parameter.
	 * @param exception	The exception (<code>Throwable</code>) parameter.
	 * @see #log(int,String)
	 */
	public void log(final int severity, final String message, final Throwable exception);
}
