package org.eclipse.soda.dk.testagent.service;

/*************************************************************************
 * Copyright (c) 2006, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Dictionary;
import junit.framework.TestResult;
import org.eclipse.soda.dk.notification.service.NotificationService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface TestAgentService {
	/**
	 * Define the service name (String) constant.
	 */
	public static final String SERVICE_NAME = TestAgentService.class.getName();

	/**
	 * Gets the description (String) value.
	 * @return	The description (<code>String</code>) value.
	 */
	public String getDescription();

	/**
	 * Gets the ID (String) value.
	 * @return	The id (<code>String</code>) value.
	 */
	public String getId();

	/**
	 * Runs a test and collects its result in a TestResult instance.
	 * @param syncService	The sync service (<code>TestSynchronizationService</code>) parameter.
	 * @param properties	The properties (<code>Dictionary</code>) parameter.
	 * @param result	The result (<code>TestResult</code>) parameter.
	 * @see #runTest(TestSynchronizationService,Dictionary)
	 */
	public void runTest(final TestSynchronizationService syncService, final Dictionary properties, final TestResult result);

	/**
	 * Runs a test using the JUnit textui.TestRunner and return the TestResult.
	 * @param syncService	The sync service (<code>TestSynchronizationService</code>) parameter.
	 * @param properties	The properties (<code>Dictionary</code>) parameter.
	 * @return	Results of the run test (<code>TestResult</code>) value.
	 * @see #runTest(TestSynchronizationService,Dictionary,TestResult)
	 */
	public TestResult runTest(final TestSynchronizationService syncService, final Dictionary properties);

	/**
	 * Sets the configuration information value.
	 * @param configurationInformation	The configuration information (<code>Dictionary</code>) parameter.
	 */
	public void setConfigurationInformation(final Dictionary configurationInformation);

	/**
	 * Sets the notification service value.
	 * @param notificationService	The notification service (<code>NotificationService</code>) parameter.
	 */
	public void setNotificationService(final NotificationService notificationService);
}
