package org.eclipse.soda.dk.testagent.test.managed;

/*************************************************************************
 * Copyright (c) 2006, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Hashtable;
import org.eclipse.soda.dk.testagent.TestAgent;
import org.eclipse.soda.dk.testagent.managed.TestAgentManaged;
import org.eclipse.soda.dk.testagent.service.TestAgentService;
import org.eclipse.soda.dk.testagent.test.TestAgentTest;
import org.eclipse.soda.dk.testagent.test.service.TestAgentTestService;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.Constants;

/**
 * test Adapter.
 * <p>
 * The device bundle activator class creates and registers the testAdapter
 * device.
 * <p>
 * The list of exported services:
 * @see org.eclipse.soda.dk.test.adapter.service.testAdapterService
 * @see org.eclipse.soda.dk.device.service.DeviceService<p>
 * See the following specification(s) for more details:
 * </p>
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestAgentTestManaged extends TestAgentManaged implements BundleActivator {
	/**
	 * Defines the class name.
	 */
	public static final String CLASS_NAME = "org.eclipse.soda.dk.testagent.test.managed.TestAgentTestManaged"; //$NON-NLS-1$

	/**
	 * Defines the service name(s) to be registered by the testAdapter bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.adapter.service.AdapterService</td>
	 * </tr>
	 * </table>
	 */
	public static final String[] EXPORTED_SERVICE_NAMES = new String[] { TestAgentService.SERVICE_NAME, TestAgentTestService.SERVICE_NAME };

	/**
	 * Create properties and return the Hashtable result.
	 * @return	Results of the create properties (<code>Hashtable</code>) value.
	 */
	public Hashtable createProperties() {
		final Hashtable properties = super.createProperties();
		properties.put(Constants.SERVICE_PID, TestAgentTestService.SERVICE_NAME);
		properties.put(Constants.SERVICE_DESCRIPTION, TestAgentTestService.SERVICE_DESCRIPTION);
		properties.put(Constants.SERVICE_VENDOR, "Eclipse"); //$NON-NLS-1$
		properties.put(Constants.SERVICE_RANKING, "6"); //$NON-NLS-1$
		return properties;
	}

	/**
	 * Creates the adapter using the specified device service.
	 * The device service to used when creating the adatper service.
	 * @see org.eclipse.soda.dk.test.adapter.testAdapter
	 * @return Object The adapter service created by this bundle.
	 */
	public TestAgent createService() {
		return new TestAgentTest();
	}

	/**
	 * Return the exported service name(s) to be registered by the testAdapter
	 * bundle.
	 * @return String[] The device's service names.
	 */
	public String[] getExportedServiceNames() {
		return EXPORTED_SERVICE_NAMES;
	}
}
