package org.eclipse.soda.dk.testcontroller;

/*************************************************************************
 * Copyright (c) 2006, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.util.ResourceBundle;
import org.eclipse.soda.dk.core.ConfigurableObject;
import org.eclipse.soda.dk.core.EscConfiguration;
import org.eclipse.soda.dk.core.service.ConfigurationService;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.testagent.service.TestSynchronizationService;
import org.eclipse.soda.dk.testcontroller.config.standard.StandardTestConfiguration;
import org.eclipse.soda.dk.testcontroller.service.TestConfigurationService;
import org.eclipse.soda.dk.testcontroller.service.TestControllerService;
import org.eclipse.soda.dk.testcontroller.service.TestSessionService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestController extends ConfigurableObject implements TestControllerService {
	/**
	 * Define the class name (String) constant.
	 */
	public static final String CLASS_NAME = TestController.class.getName();

	/**
	 * Define the run single requires (int) constant.
	 */
	public static final int RUN_SINGLE_REQUIRES = 7050;

	/**
	 * Define the creating with factory pid (int) constant.
	 */
	public static final int CREATING_WITH_FACTORY_PID = 7051;

	/**
	 * Define the creating with pid (int) constant.
	 */
	public static final int CREATING_WITH_PID = 7052;

	/**
	 * Define the no config match filter (int) constant.
	 */
	public static final int NO_CONFIG_MATCH_FILTER = 7053;

	/**
	 * Define the deleting with pid (int) constant.
	 */
	public static final int DELETING_WITH_PID = 7054;

	/**
	 * Define the unable deleting with pid (int) constant.
	 */
	public static final int UNABLE_DELETING_WITH_PID = 7055;

	/**
	 * Define the no test match filter (int) constant.
	 */
	public static final int NO_TEST_MATCH_FILTER = 7056;

	/**
	 * Define the no test match filter class (int) constant.
	 */
	public static final int NO_TEST_MATCH_FILTER_CLASS = 7057;

	/**
	 * Define the updating with pid (int) constant.
	 */
	public static final int UPDATING_WITH_PID = 7058;

	/**
	 * Define the no osgi support (int) constant.
	 */
	public static final int NO_OSGI_SUPPORT = 7059;

	/**
	 * Define the error in test (int) constant.
	 */
	public static final int ERROR_IN_TEST = 7065;

	/**
	 * Define the test failed (int) constant.
	 */
	public static final int TEST_FAILED = 7066;

	/**
	 * Define the error in test run (int) constant.
	 */
	public static final int ERROR_IN_TEST_RUN = 7067;

	/**
	 * Define the running (int) constant.
	 */
	public static final int RUNNING = 7068;

	/**
	 * Define the used filter (int) constant.
	 */
	public static final int USED_FILTER = 7069;

	/**
	 * Define the test failed while run (int) constant.
	 */
	public static final int TEST_FAILED_WHILE_RUN = 7070;

	/**
	 * Define the default resource bundle (ResourceBundle) field.
	 */
	public static ResourceBundle DefaultResourceBundle = Nls.getResourceBundle(TestControllerResourceBundle.class);

	/**
	 * Define the edgeConfigurationService service (EdgeConfigurationService)
	 * field.
	 */
	protected TestConfigurationService testConfigurationService;

	/**
	 * Constructs an instance of this class.
	 */
	public TestController() {
		super();
		ConfigurationService defaultConfiguration = EscConfiguration.getConfiguration();
		setConfigurationInformation(defaultConfiguration.getProperties());
		setTestConfigurationService(new StandardTestConfiguration());
	}

	/**
	 * Create test session with the specified sync service parameter and return the TestSessionService result.
	 * @param syncService	The sync service (<code>TestSynchronizationService</code>) parameter.
	 * @return	Results of the create test session (<code>TestSessionService</code>) value.
	 */
	public TestSessionService createTestSession(final TestSynchronizationService syncService) {
		return new TestSession(this.testConfigurationService, syncService);
	}

	/**
	 * Gets the test configuration service value.
	 * @return	The test configuration service (<code>TestConfigurationService</code>) value.
	 * @see #setTestConfigurationService(TestConfigurationService)
	 */
	public TestConfigurationService getTestConfigurationService() {
		return this.testConfigurationService;
	}

	/**
	 * Sets the notification service value.
	 * @param notificationService	The notification service (<code>NotificationService</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void setNotificationService(final NotificationService notificationService) throws IOException {
		getTestConfigurationService().setNotificationService(notificationService);
	}

	/**
	 * Sets the test configuration service value.
	 * @param testConfigurationService	The test configuration service (<code>TestConfigurationService</code>) parameter.
	 * @see #getTestConfigurationService()
	 */
	public void setTestConfigurationService(final TestConfigurationService testConfigurationService) {
		this.testConfigurationService = testConfigurationService;
	}
}
