package org.eclipse.soda.dk.testcontroller.config.standard;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.util.Dictionary;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.testagent.service.TestAgentService;
import org.eclipse.soda.dk.testcontroller.TestController;
import org.eclipse.soda.dk.testcontroller.service.TestConfigurationService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class StandardTestConfiguration implements TestConfigurationService {
	/**
	 * Define the notification service (NotificationService) field.
	 */
	private NotificationService notificationService;

	/**
	 * Create factory configuration with the specified factory pid, bundle location and properties parameters.
	 * @param factoryPid	The factory pid (<code>String</code>) parameter.
	 * @param bundleLocation	The bundle location (<code>String</code>) parameter.
	 * @param properties	The properties (<code>Dictionary</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void createFactoryConfiguration(final String factoryPid, final String bundleLocation, final Dictionary properties) throws IOException {
		throwUnsupportedOperation();
	}

	/**
	 * Create or update configuration with the specified pid, bundle location and properties parameters.
	 * @param pid	The pid (<code>String</code>) parameter.
	 * @param bundleLocation	The bundle location (<code>String</code>) parameter.
	 * @param properties	The properties (<code>Dictionary</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void createOrUpdateConfiguration(final String pid, final String bundleLocation, final Dictionary properties) throws IOException {
		throwUnsupportedOperation();
	}

	/**
	 * Delete configurations with the specified filter parameter.
	 * @param filter	The filter (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 * @see #updateConfigurations(String,Dictionary)
	 */
	public void deleteConfigurations(final String filter) throws IOException {
		throwUnsupportedOperation();
	}

	/**
	 * Find tests with the specified filter and class name parameters and return the TestAgentService[] result.
	 * @param filter	The filter (<code>String</code>) parameter.
	 * @param className	The class name (<code>String</code>) parameter.
	 * @return	Results of the find tests (<code>TestAgentService[]</code>) value.
	 * @throws IOException IOException.
	 */
	public TestAgentService[] findTests(final String filter, final String className) throws IOException {
		if (filter != null && filter.length() > 0) {
			throwUnsupportedOperation();
		}
		try {
			Class agentClass = Class.forName(className);
			TestAgentService testAgent = (TestAgentService) agentClass.newInstance();
			testAgent.setNotificationService(this.notificationService);
			return new TestAgentService[] { testAgent };
		} catch (final Exception e) {
			return new TestAgentService[0];
		}
	}

	/**
	 * Sets the notification service value.
	 * @param notificationService	The notification service (<code>NotificationService</code>) parameter.
	 */
	public void setNotificationService(final NotificationService notificationService) {
		this.notificationService = notificationService;
	}

	/**
	 * Throw unsupported operation.
	 * @throws IOException IOException.
	 */
	private void throwUnsupportedOperation() throws IOException {
		throw new IOException(TestController.DefaultResourceBundle.getString(Integer.toString(TestController.NO_OSGI_SUPPORT)));
	}

	/**
	 * Update configurations with the specified filter and properties parameters.
	 * @param filter	The filter (<code>String</code>) parameter.
	 * @param properties	The properties (<code>Dictionary</code>) parameter.
	 * @throws IOException IOException.
	 * @see #deleteConfigurations(String)
	 */
	public void updateConfigurations(final String filter, final Dictionary properties) throws IOException {
		throwUnsupportedOperation();
	}
}
