package org.eclipse.soda.dk.testcontroller.remote.rmi;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.net.ServerSocket;
import java.net.Socket;
import java.rmi.server.RemoteObject;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class ControllerRegistry {
	/**
	 * Define the registry port (int) constant.
	 */
	public static final int REGISTRY_PORT = 2099;

	/**
	 * Define the port (int) field.
	 */
	private int port;

	/**
	 * Define the server socket (ServerSocket) field.
	 */
	ServerSocket serverSocket;

	/**
	 * Define the test controller (RemoteTestController) field.
	 */
	RemoteTestController testController;

	/**
	 * Constructs an instance of this class from the specified port parameter.
	 * @param port	The port (<code>int</code>) parameter.
	 */
	public ControllerRegistry(final int port) {
		if (port <= 0) {
			this.port = ControllerRegistry.REGISTRY_PORT;
		} else {
			this.port = port;
		}
	}

	/**
	 * Bind with the specified test controller parameter.
	 * @param testController	The test controller (<code>RemoteTestController</code>) parameter.
	 * @throws IOException IOException.
	 */
	public synchronized void bind(final RemoteTestController testController) throws IOException {
		if (this.testController != null) {
			unbind();
		}
		this.serverSocket = new ServerSocket(this.port);
		this.testController = testController;
		Runnable requestHandler = new Runnable() {
			/**
			 * Run.
			 */
			public void run() {
				while (ControllerRegistry.this.serverSocket != null) {
					Socket socket;
					try {
						socket = ControllerRegistry.this.serverSocket.accept();
						ObjectOutputStream out = new ObjectOutputStream(socket.getOutputStream());
						out.writeObject(RemoteObject.toStub(ControllerRegistry.this.testController));
						out.flush();
						socket.close();
					} catch (final IOException e) {
						/* ignore exception */
					}
				}
			}
		};
		new Thread(requestHandler).start();
	}

	/**
	 * Gets the test controller (RemoteTestController) value.
	 * @return	The test controller (<code>RemoteTestController</code>) value.
	 */
	public RemoteTestController getTestController() {
		return this.testController;
	}

	/**
	 * Unbind.
	 * @throws IOException IOException.
	 */
	public synchronized void unbind() throws IOException {
		if (this.testController != null) {
			this.serverSocket.close();
			this.serverSocket = null;
			this.testController = null;
		}
	}
}
