package org.eclipse.soda.dk.testcontroller.remote.rmi;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.ObjectInputStream;
import java.net.Socket;
import java.rmi.RemoteException;
import java.util.ResourceBundle;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.sat.core.util.LogUtility;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class LocateController {
	/**
	 * Define the controller not found (int) constant.
	 */
	public static final int CONTROLLER_NOT_FOUND = 7120;

	/**
	 * Define the failed to bind controller (int) constant.
	 */
	public static final int FAILED_TO_BIND_CONTROLLER = 7121;

	/**
	 * Define the failed to unbind controller (int) constant.
	 */
	public static final int FAILED_TO_UNBIND_CONTROLLER = 7122;

	/**
	 * Define the default resource bundle (ResourceBundle) field.
	 */
	public static ResourceBundle DefaultResourceBundle = Nls.getResourceBundle(LocateControllerResourceBundle.class);

	/**
	 * Create registry with the specified port parameter and return the ControllerRegistry result.
	 * @param port	The port (<code>int</code>) parameter.
	 * @return	Results of the create registry (<code>ControllerRegistry</code>) value.
	 * @throws RemoteException Remote Exception.
	 */
	public static ControllerRegistry createRegistry(final int port) throws RemoteException {
		return new ControllerRegistry(port);
	}

	/**
	 * Get controller with the specified host and port parameters and return the RemoteTestController result.
	 * @param host	The host (<code>String</code>) parameter.
	 * @param port	The port (<code>int</code>) parameter.
	 * @return	Results of the get controller (<code>RemoteTestController</code>) value.
	 */
	public static RemoteTestController getController(final String host, final int port) {
		int p;
		String h;
		if (port <= 0) {
			p = ControllerRegistry.REGISTRY_PORT;
		} else {
			p = port;
		}
		if (host == null || host.length() == 0) {
			try {
				h = java.net.InetAddress.getLocalHost().getHostAddress();
			} catch (Exception e) {
				h = ""; //$NON-NLS-1$
			}
		} else {
			h = host;
		}
		RemoteTestController testController;
		try {
			Socket socket = new Socket(h, p);
			ObjectInputStream in = new ObjectInputStream(socket.getInputStream());
			testController = (RemoteTestController) in.readObject();
			socket.close();
		} catch (Exception e) {
			Object parms[] = { h, Integer.toString(p), e.getMessage() };
			LogUtility.logInfo(Nls.format(LocateController.DefaultResourceBundle.getString(Integer.toString(LocateController.CONTROLLER_NOT_FOUND)), parms));
			testController = null;
		}
		return testController;
	}
}
