package org.eclipse.soda.dk.testcontroller.remote.rmi;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.HashMap;
import java.util.Map;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.testcontroller.service.ControllerLocaterService;
import org.eclipse.soda.dk.testcontroller.service.TestControllerService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class RemoteControllerLocater implements ControllerLocaterService {
	/**
	 * Define the remote test controllers (Map) field.
	 */
	private Map remoteTestControllers = new HashMap();

	/**
	 * Find controller with the specified id parameter and return the TestControllerService result.
	 * @param id The id (<code>String</code>) parameter.
	 * @return Results of the find controller (<code>TestControllerService</code>) value.
	 */
	public synchronized TestControllerService findController(final String id) {
		String hostAndPort = id == null ? "127.0.0.1" : id; //$NON-NLS-1$
		if (hostAndPort.indexOf(':') == -1) {
			hostAndPort += ":" + ControllerRegistry.REGISTRY_PORT; //$NON-NLS-1$
		}
		TestControllerService remoteTestController = (TestControllerService) this.remoteTestControllers.get(hostAndPort);
		if (remoteTestController == null) {
			int pos = hostAndPort.indexOf(':');
			String host = hostAndPort.substring(0, pos);
			int port = Integer.parseInt(hostAndPort.substring(pos + 1));
			try {
				remoteTestController = LocateController.getController(host, port);
				this.remoteTestControllers.put(hostAndPort, remoteTestController);
			} catch (Exception e) {
				/* Logging an error is inappropriate here, as this is a normal case. */
				remoteTestController = null;
			}
		}
		return remoteTestController;
	}

	/**
	 * Sets the notification service value.
	 * @param notificationService	The notification service (<code>NotificationService</code>) parameter.
	 */
	public void setNotificationService(final NotificationService notificationService) {
		/* do nothing */
	}
}
