package org.eclipse.soda.dk.testcontroller.remote.rmi;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.rmi.Remote;
import java.util.Dictionary;
import org.eclipse.soda.dk.testcontroller.service.TestSessionService;
import org.osgi.framework.InvalidSyntaxException;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface RemoteTestSession extends TestSessionService, Remote {
	/**
	 * Add global test run listener with the specified global run listener parameter.
	 * @param globalRunListener The global run listener (<code>LocalTestRunListener</code>) parameter.
	 * @throws IOException IOException.
	 * @see #removeGlobalTestRunListener(LocalTestRunListener)
	 */
	public void addGlobalTestRunListener(final LocalTestRunListener globalRunListener) throws IOException;

	/**
	 * Remove global test run listener with the specified global run listener parameter.
	 * @param globalRunListener The global run listener (<code>LocalTestRunListener</code>) parameter.
	 * @throws IOException IOException.
	 * @see #addGlobalTestRunListener(LocalTestRunListener)
	 */
	public void removeGlobalTestRunListener(final LocalTestRunListener globalRunListener) throws IOException;

	/**
	 * Run multiple tests with the specified run id, filter, class name, properties and run listener parameters.
	 * @param actionId The action id (<code>String</code>) parameter.
	 * @param runId The run id (<code>String</code>) parameter.
	 * @param filter The filter (<code>String</code>) parameter.
	 * @param className The class name (<code>String</code>) parameter.
	 * @param properties The properties (<code>Dictionary</code>) parameter.
	 * @param runListener The run listener (<code>LocalTestRunListener</code>) parameter.
	 * @throws InvalidSyntaxException Invalid Syntax Exception.
	 * @throws IOException IOException.
	 */
	public void runMultipleTests(final String actionId, final String runId, final String filter, final String className, final Dictionary properties, final LocalTestRunListener runListener) throws InvalidSyntaxException, IOException;

	/**
	 * Run single test with the specified run id, filter, class name, properties and run listener parameters.
	 * @param actionId The action id (<code>String</code>) parameter.
	 * @param runId The run id (<code>String</code>) parameter.
	 * @param filter The filter (<code>String</code>) parameter.
	 * @param className The class name (<code>String</code>) parameter.
	 * @param properties The properties (<code>Dictionary</code>) parameter.
	 * @param runListener The run listener (<code>LocalTestRunListener</code>) parameter.
	 * @throws InvalidSyntaxException Invalid Syntax Exception.
	 * @throws IOException IOException.
	 */
	public void runSingleTest(final String actionId, final String runId, final String filter, final String className, final Dictionary properties, final LocalTestRunListener runListener) throws InvalidSyntaxException, IOException;
}
