package org.eclipse.soda.dk.testcontroller.remote.rmi;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.testagent.service.TestSynchronizationService;
import org.eclipse.soda.dk.testcontroller.service.TestControllerService;
import org.eclipse.soda.dk.testcontroller.service.TestSessionService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestControllerSkeleton extends UnicastRemoteObject implements RemoteTestController {
	/**
	 * Define the serial version uid (long) constant.
	 */
	private static final long serialVersionUID = -3868796373347936617L;

	/**
	 * Define the delegate (TestControllerService) field.
	 */
	private TestControllerService delegate;

	/**
	 * Constructs an instance of this class from the specified delegate parameter.
	 * @param delegate	The delegate (<code>TestControllerService</code>) parameter.
	 * @throws RemoteException Remote Exception.
	 */
	public TestControllerSkeleton(final TestControllerService delegate) throws RemoteException {
		this.delegate = delegate;
	}

	/**
	 * Create test session with the specified sync service parameter and return the TestSessionService result.
	 * @param syncService	The sync service (<code>TestSynchronizationService</code>) parameter.
	 * @return	Results of the create test session (<code>TestSessionService</code>) value.
	 * @throws IOException IOException.
	 * @see #createTestSession(LocalTestSynchronization)
	 */
	public TestSessionService createTestSession(final TestSynchronizationService syncService) throws IOException {
		TestSessionService remoteTestSession = this.delegate.createTestSession(syncService);
		return new TestSessionSkeleton(remoteTestSession);
	}

	/**
	 * Create test session with the specified sync service parameter and return the TestSessionService result.
	 * @param syncService The sync service (<code>LocalTestSynchronization</code>) parameter.
	 * @return Results of the create test session (<code>TestSessionService</code>) value.
	 * @throws IOException IOException.
	 * @see #createTestSession(TestSynchronizationService)
	 */
	public TestSessionService createTestSession(final LocalTestSynchronization syncService) throws IOException {
		TestSessionService remoteTestSession = this.delegate.createTestSession(syncService);
		return new TestSessionSkeleton(remoteTestSession);
	}

	/**
	 * Sets the notification service value.
	 * @param notificationService	The notification service (<code>NotificationService</code>) parameter.
	 */
	public void setNotificationService(final NotificationService notificationService) {
		/* do nothing */
	}
}
