package org.eclipse.soda.dk.testcontroller.remote.rmi;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import org.eclipse.soda.dk.testcontroller.service.TestRunListenerService;

/**
 * @author IBM
 * @version 1.2.0
 */
public class TestRunListenerSkeleton extends UnicastRemoteObject implements RemoteTestRunListener {
	/**
	 * Define the serial version uid (long) constant.
	 */
	private static final long serialVersionUID = -1799351635621331224L;

	/**
	 * Define the delegate (TestRunListenerService) field.
	 */
	private TestRunListenerService delegate;

	/**
	 * Constructs an instance of this class from the specified delegate parameter.
	 * @param delegate	The delegate (<code>TestRunListenerService</code>) parameter.
	 * @throws RemoteException Remote Exception.
	 */
	public TestRunListenerSkeleton(final TestRunListenerService delegate) throws RemoteException {
		this.delegate = delegate;
	}

	/**
	 * Test ended with the specified run id and test name parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 * @see #testRunEnded(String)
	 */
	public void testEnded(final String runId, final String testName) throws IOException {
		this.delegate.testEnded(runId, testName);
	}

	/**
	 * Test error with the specified run id, test name and trace parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @param trace	The trace (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 * @see #testRunError(String,String,String)
	 */
	public void testError(final String runId, final String testName, final String trace) throws IOException {
		this.delegate.testError(runId, testName, trace);
	}

	/**
	 * Test failed with the specified run id, test name and trace parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @param trace	The trace (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void testFailed(final String runId, final String testName, final String trace) throws IOException {
		this.delegate.testFailed(runId, testName, trace);
	}

	/**
	 * Test run ended with the specified run id parameter.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void testRunEnded(final String runId) throws IOException {
		this.delegate.testRunEnded(runId);
	}

	/**
	 * Test run error with the specified run id, message and detail parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param message	The message (<code>String</code>) parameter.
	 * @param detail	The detail (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void testRunError(final String runId, final String message, final String detail) throws IOException {
		this.delegate.testRunError(runId, message, detail);
	}

	/**
	 * Test run started with the specified run id parameter.
	 * @param actionId
	 *		The action ID (<code>String</code>) parameter.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void testRunStarted(final String actionId, final String runId) throws IOException {
		this.delegate.testRunStarted(actionId, runId);
	}

	/**
	 * Test started with the specified run id and test name parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 * @see #testRunStarted(String,String)
	 */
	public void testStarted(final String runId, final String testName) throws IOException {
		this.delegate.testStarted(runId, testName);
	}
}
