package org.eclipse.soda.dk.testcontroller.remote.rmi;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import org.eclipse.soda.dk.testagent.service.TestSynchronizationService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestSynchronizationSkeleton extends UnicastRemoteObject implements LocalTestSynchronization, RemoteTestSynchronization {
	/**
	 * Define the serial version uid (long) constant.
	 */
	private static final long serialVersionUID = -8663714067311424772L;

	/**
	 * Define the delegate (TestSynchronizationService) field.
	 */
	private TestSynchronizationService delegate;

	/**
	 * Constructs an instance of this class from the specified delegate parameter.
	 * @param delegate	The delegate (<code>TestSynchronizationService</code>) parameter.
	 * @throws RemoteException Remote Exception.
	 */
	public TestSynchronizationSkeleton(final TestSynchronizationService delegate) throws RemoteException {
		this.delegate = delegate;
	}

	/**
	 * Request confirmation with the specified prompt and test name parameters and return the boolean result.
	 * @param prompt	The prompt (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @return	Results of the request confirmation (<code>boolean</code>) value.
	 * @throws InterruptedException Interrupted Exception.
	 * @throws IOException IOException.
	 */
	public boolean requestConfirmation(final String prompt, final String testName) throws InterruptedException, IOException {
		return this.delegate.requestConfirmation(prompt, testName);
	}
}
