package org.eclipse.soda.dk.testcontroller.service;

/*************************************************************************
 * Copyright (c) 2006, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface TestRunListenerService {
	/**
	 * Test ended with the specified run id and test name parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 * @see #testRunEnded(String)
	 */
	public void testEnded(final String runId, final String testName) throws IOException;

	/**
	 * Test error with the specified run id, test name and trace parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @param trace	The trace (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 * @see #testRunError(String,String,String)
	 */
	public void testError(final String runId, final String testName, final String trace) throws IOException;

	/**
	 * Test failed with the specified run id, test name and trace parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @param trace	The trace (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void testFailed(final String runId, final String testName, final String trace) throws IOException;

	/**
	 * Test run ended with the specified run id parameter.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void testRunEnded(final String runId) throws IOException;

	/**
	 * Test run error with the specified run id, message and detail parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param message	The message (<code>String</code>) parameter.
	 * @param detail	The detail (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void testRunError(final String runId, final String message, final String detail) throws IOException;

	/**
	 * Test run started with the specified run id parameter.
	 * @param actionId The action id (<code>String</code>) parameter.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 */
	public void testRunStarted(final String actionId, final String runId) throws IOException;

	/**
	 * Test started with the specified run id and test name parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @throws IOException IOException.
	 * @see #testRunStarted(String,String)
	 */
	public void testStarted(final String runId, final String testName) throws IOException;
}
