package org.eclipse.soda.dk.testcontroller.service;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.util.Dictionary;
import org.osgi.framework.InvalidSyntaxException;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface TestSessionService {
	/**
	 * Registers a TestRunListener
	 * @param globalRunListener	The global run listener (<code>TestRunListenerService</code>) parameter.
	 * @throws IOException IOException.
	 * @see #removeGlobalTestRunListener(TestRunListenerService)
	 */
	public void addGlobalTestRunListener(final TestRunListenerService globalRunListener) throws IOException;

	/**
	 * Close.
	 * @throws IOException IOException.
	 */
	public void close() throws IOException;

	/**
	 * Gets the test configuration service value.
	 * @return	The test configuration service (<code>TestConfigurationService</code>) value.
	 * @throws IOException IOException.
	 */
	public TestConfigurationService getTestConfigurationService() throws IOException;

	/**
	 * Interrupt.
	 * @throws IOException IOException.
	 */
	public void interrupt() throws IOException;

	/**
	 * Gets the interrupted (boolean) value.
	 * @return the interrupted status
	 * @throws IOException IOException.
	 */
	public boolean isInterrupted() throws IOException;

	/**
	 * Unregisters a TestListener
	 * @param globalRunListener	The global run listener (<code>TestRunListenerService</code>) parameter.
	 * @throws IOException IOException.
	 * @see #addGlobalTestRunListener(TestRunListenerService)
	 */
	public void removeGlobalTestRunListener(final TestRunListenerService globalRunListener) throws IOException;

	/**
	 * Run multiple tests with the specified run id, filter, class name, properties and run listener parameters.
	 * @param actionId The action id (<code>String</code>) parameter.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param filter	The filter (<code>String</code>) parameter.
	 * @param className	The class name (<code>String</code>) parameter.
	 * @param properties	The properties (<code>Dictionary</code>) parameter.
	 * @param runListener	The run listener (<code>TestRunListenerService</code>) parameter.
	 * @throws InvalidSyntaxException Invalid Syntax Exception.
	 * @throws IOException IOException.
	 */
	public void runMultipleTests(final String actionId, final String runId, final String filter, final String className, final Dictionary properties, final TestRunListenerService runListener) throws InvalidSyntaxException, IOException;

	/**
	 * Run single test with the specified run id, filter, class name, properties and run listener parameters.
	 * @param actionId The action id (<code>String</code>) parameter.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param filter	The filter (<code>String</code>) parameter.
	 * @param className	The class name (<code>String</code>) parameter.
	 * @param properties	The properties (<code>Dictionary</code>) parameter.
	 * @param runListener	The run listener (<code>TestRunListenerService</code>) parameter.
	 * @throws InvalidSyntaxException Invalid Syntax Exception.
	 * @throws IOException IOException.
	 */
	public void runSingleTest(final String actionId, final String runId, final String filter, final String className, final Dictionary properties, final TestRunListenerService runListener) throws InvalidSyntaxException, IOException;
}
