package org.eclipse.soda.dk.testcontroller.test;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.ResourceBundle;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.testagent.test.TestAgentTest;
import org.eclipse.soda.dk.testcontroller.TestController;
import org.eclipse.soda.dk.testcontroller.console.TestControllerConsole;
import org.eclipse.soda.dk.testcontroller.service.TestSessionService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestControllerTest {
	/**
	 * Define the unexpected exception (int) constant.
	 */
	public static final int UNEXPECTED_EXCEPTION = 7090;

	/**
	 * Define the test unexpectedly found (int) constant.
	 */
	public static final int TEST_UNEXPECTEDLY_FOUND = 7091;

	/**
	 * Define the default resource bundle (ResourceBundle) field.
	 */
	public static ResourceBundle DefaultResourceBundle = Nls.getResourceBundle(TestControllerTestResourceBundle.class);

	/**
	 * Main with the specified arguments parameter.
	 * @param arguments
	 *		The arguments (<code>String[]</code>) parameter.
	 */
	public static void main(final String[] arguments) {
		TestController testController = new TestController();
		TestControllerConsole console = new TestControllerConsole();
		String runId = null;
		String actionId = "Action1"; //$NON-NLS-1$
		try {
			TestSessionService testSession = testController.createTestSession(console);
			testSession.addGlobalTestRunListener(console);
			runId = "TestA"; //$NON-NLS-1$
			testSession.runSingleTest(actionId, runId, null, TestAgentTest.CLASS_NAME, null, null);
			runId = "TestB"; //$NON-NLS-1$
			testSession.runSingleTest(actionId, runId, null, TestAgentTest.CLASS_NAME, null, null);
			try {
				runId = "TestC"; //$NON-NLS-1$
				testSession.runSingleTest(actionId, runId, "UnexpectedFilter", "NonExistingClassName", null, null); //$NON-NLS-1$ //$NON-NLS-2$
				console.testRunError(runId, TestControllerTest.DefaultResourceBundle.getString(Integer.toString(TestControllerTest.TEST_UNEXPECTEDLY_FOUND)), null);
			} catch (Exception expectedException) {
				/* Ignore, the test is supposed not to be found. */
			}
			testSession.close();
		} catch (Exception unexpectedException) {
			console.testRunError(runId, TestControllerTest.DefaultResourceBundle.getString(Integer.toString(TestControllerTest.UNEXPECTED_EXCEPTION)), unexpectedException.getMessage());
		}
	}
}
