package org.eclipse.soda.dk.testcontroller.test.bundle;

/*************************************************************************
 * Copyright (c) 2006, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Properties;
import java.util.ResourceBundle;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.testagent.service.TestSynchronizationService;
import org.eclipse.soda.dk.testagent.test.TestAgentTest;
import org.eclipse.soda.dk.testcontroller.service.TestConfigurationService;
import org.eclipse.soda.dk.testcontroller.service.TestControllerService;
import org.eclipse.soda.dk.testcontroller.service.TestSessionService;
import org.eclipse.soda.sat.core.framework.BaseBundleActivator;
import org.eclipse.soda.sat.core.util.LogUtility;
import org.osgi.framework.BundleActivator;

/**
 * test Adapter.
 * <p>
 * The device bundle activator class creates and registers the testAdapter
 * device.
 * <p>
 * The list of exported services:
 * @see org.eclipse.soda.dk.test.adapter.service.testAdapterService
 * @see org.eclipse.soda.dk.device.service.DeviceService<p>
 * See the following specification(s) for more details:
 * </p>
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestControllerTestBundle extends BaseBundleActivator implements BundleActivator {
	/**
	 * Defines the class name.
	 */
	public static final String CLASS_NAME = "org.eclipse.soda.dk.testcontroller.test.bundle.TestControllerTestBundle"; //$NON-NLS-1$

	/**
	 * Defines the service name(s) to be registered by the testAdapter bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.adapter.service.AdapterService</td>
	 * </tr>
	 * </table>
	 */
	public static final String[] EXPORTED_SERVICE_NAMES = BaseBundleActivator.NO_SERVICES;

	/**
	 * Defines the imported service name(s) to be registered by the testAdapter
	 * bundle. <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.test.adapter.service.testAdapterService</td>
	 * </tr>
	 * <tr>
	 * <td>org.eclipse.soda.dk.notification.service.NotificationService</td>
	 * </tr>
	 * </table>
	 */
	public static final String[] IMPORTED_SERVICE_NAMES = new String[] { TestControllerService.SERVICE_NAME };

	/**
	 * Define message  (int) constants.
	 */
	public static final int TEST_ENDED = 7100;

	/**
	 * Define the test error (int) constant.
	 */
	public static final int TEST_ERROR = 7101;

	/**
	 * Define the test failed (int) constant.
	 */
	public static final int TEST_FAILED = 7102;

	/**
	 * Define the testrun ended (int) constant.
	 */
	public static final int TESTRUN_ENDED = 7103;

	/**
	 * Define the testrun error (int) constant.
	 */
	public static final int TESTRUN_ERROR = 7104;

	/**
	 * Define the testrun started (int) constant.
	 */
	public static final int TESTRUN_STARTED = 7105;

	/**
	 * Define the test started (int) constant.
	 */
	public static final int TEST_STARTED = 7106;

	/**
	 * Define the bundle activated (int) constant.
	 */
	public static final int BUNDLE_ACTIVATED = 7107;

	/**
	 * Define the test invalid filter found (int) constant.
	 */
	public static final int TEST_INVALID_FILTER_FOUND = 7108;

	/**
	 * Define the test invalid filter not found (int) constant.
	 */
	public static final int TEST_INVALID_FILTER_NOT_FOUND = 7109;

	/**
	 * Define the bundle test failed (int) constant.
	 */
	public static final int BUNDLE_TEST_FAILED = 7110;

	/**
	 * Define the bundle returns (int) constant.
	 */
	public static final int BUNDLE_RETURNS = 7111;

	/**
	 * Define the default resource bundle (ResourceBundle) field.
	 */
	public static ResourceBundle DefaultResourceBundle = Nls.getResourceBundle(TestControllerTestBundleResourceBundle.class);

	/**
	 * Activate.
	 */
	protected void activate() {
		LogUtility.logInfo(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.BUNDLE_ACTIVATED)));
		TestControllerService testController = (TestControllerService) getImportedService(TestControllerService.SERVICE_NAME);
		TestSynchronizationService syncService = null;
		String actionId = "Action1"; //$NON-NLS-1$
		try {
			TestSessionService testSession = testController.createTestSession(syncService);
			testSession.addGlobalTestRunListener(new TestRunConsolePrinter());
			TestConfigurationService testConfigurationService = testSession.getTestConfigurationService();
			Properties props;
			/* Create TestAgentTest testA and testB */
			props = new Properties();
			props.put("testId", "testA"); //$NON-NLS-1$ //$NON-NLS-2$
			props.put("testKey", "testValue"); //$NON-NLS-1$//$NON-NLS-2$
			testConfigurationService.createFactoryConfiguration("org.eclipse.soda.dk.testagent.test.factory.TestAgentTestFactory", null, props); //$NON-NLS-1$
			/* Create TestAgentTest testB */
			props = new Properties();
			props.put("testId", "testB"); //$NON-NLS-1$//$NON-NLS-2$
			props.put("testKey", "testValue"); //$NON-NLS-1$//$NON-NLS-2$
			testConfigurationService.createFactoryConfiguration("org.eclipse.soda.dk.testagent.test.factory.TestAgentTestFactory", null, props); //$NON-NLS-1$
			/* Run tests */
			testSession.runSingleTest(actionId, "TestA", "(testId=testA)", null, null, null); //$NON-NLS-1$ //$NON-NLS-2$
			testSession.runSingleTest(actionId, "TestB", "(testId=testB)", TestAgentTest.CLASS_NAME, null, null); //$NON-NLS-1$ //$NON-NLS-2$
			testSession.runMultipleTests(actionId, "TestAandB", "(testId=*)", null, null, null); //$NON-NLS-1$ //$NON-NLS-2$
			testSession.runSingleTest(actionId, "TestC", "(testId=testC)", null, null, null); //$NON-NLS-1$ //$NON-NLS-2$
			testSession.runSingleTest(actionId, "TestC", "(service.pid=*)", "NonExistingClassName", null, null); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
			/* Invalid filter */
			try {
				testSession.runSingleTest(actionId, "TestC", "invalid filter", null, null, null); //$NON-NLS-1$ //$NON-NLS-2$
				System.err.println(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.TEST_INVALID_FILTER_FOUND)));
			} catch (Exception expectedException) {
				Object[] parms = { expectedException.getMessage() };
				System.out.println(Nls.format(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.TEST_INVALID_FILTER_NOT_FOUND)), parms));
			}
			testSession.close();
			/* Delete all configured tests */
			testConfigurationService.deleteConfigurations("(service.pid=org.eclipse.soda.dk.testagent.test.factory.TestAgentTest*)"); //$NON-NLS-1$
		} catch (Exception e) {
			Object[] parms = { e };
			LogUtility.logError(Nls.format(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.TEST_FAILED)), parms));
		}
		LogUtility.logInfo(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.BUNDLE_RETURNS)));
	}

	/**
	 * Return the exported service name(s) to be registered by the testAdapter
	 * bundle.
	 * @return String[] The device's service names.
	 */
	public String[] getExportedServiceNames() {
		return EXPORTED_SERVICE_NAMES;
	}

	/**
	 * Return the imported service name(s) to be registered by the testAdapter
	 * bundle.
	 * @return String[] The imported service names.
	 */
	public String[] getImportedServiceNames() {
		return IMPORTED_SERVICE_NAMES;
	}
}
