package org.eclipse.soda.dk.testcontroller.test.bundle;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.testcontroller.service.TestRunListenerService;
import org.eclipse.soda.sat.core.util.LogUtility;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestRunConsolePrinter implements TestRunListenerService {
	/**
	 * Test ended with the specified run id and test name parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @see #testRunEnded(String)
	 */
	public synchronized void testEnded(final String runId, final String testName) {
		Object[] parms = { runId, testName };
		LogUtility.logInfo(Nls.format(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.TEST_ENDED)), parms));
	}

	/**
	 * Test error with the specified run id, test name and trace parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @param trace	The trace (<code>String</code>) parameter.
	 * @see #testRunError(String,String,String)
	 */
	public synchronized void testError(final String runId, final String testName, final String trace) {
		Object[] parms = { runId, testName, trace };
		LogUtility.logError(Nls.format(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.TEST_ERROR)), parms));
	}

	/**
	 * Test failed with the specified run id, test name and trace parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @param trace	The trace (<code>String</code>) parameter.
	 */
	public synchronized void testFailed(final String runId, final String testName, final String trace) {
		Object[] parms = { runId, testName, trace };
		LogUtility.logError(Nls.format(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.TEST_FAILED)), parms));
	}

	/**
	 * Test run ended with the specified run id parameter.
	 * @param runId	The run id (<code>String</code>) parameter.
	 */
	public synchronized void testRunEnded(final String runId) {
		Object[] parms = { runId };
		LogUtility.logInfo(Nls.format(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.TESTRUN_ENDED)), parms));
	}

	/**
	 * Test run error with the specified run id, message and detail parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param message	The message (<code>String</code>) parameter.
	 * @param detail	The detail (<code>String</code>) parameter.
	 */
	public synchronized void testRunError(final String runId, final String message, final String detail) {
		Object[] parms = { runId, message, detail };
		LogUtility.logError(Nls.format(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.TESTRUN_ERROR)), parms));
	}

	/**
	 * Test run started with the specified run id parameter.
	 * @param actionId The action id (<code>String</code>) parameter.
	 * @param runId	The run id (<code>String</code>) parameter.
	 */
	public synchronized void testRunStarted(final String actionId, final String runId) {
		Object[] parms = { runId };
		LogUtility.logInfo(Nls.format(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.TESTRUN_STARTED)), parms));
	}

	/**
	 * Test started with the specified run id and test name parameters.
	 * @param runId	The run id (<code>String</code>) parameter.
	 * @param testName	The test name (<code>String</code>) parameter.
	 * @see #testRunStarted(String,String)
	 */
	public synchronized void testStarted(final String runId, final String testName) {
		Object[] parms = { runId, testName };
		LogUtility.logInfo(Nls.format(TestControllerTestBundle.DefaultResourceBundle.getString(Integer.toString(TestControllerTestBundle.TEST_STARTED)), parms));
	}
}
