package org.eclipse.soda.dk.testmanager;

/*************************************************************************
 * Copyright (c) 2006, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.FileReader;
import java.io.InputStreamReader;
import java.io.Reader;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.List;
import java.util.ResourceBundle;
import java.util.Vector;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;
import org.eclipse.soda.dk.core.ConfigurableObject;
import org.eclipse.soda.dk.core.EscConfiguration;
import org.eclipse.soda.dk.core.EscObject;
import org.eclipse.soda.dk.core.service.ConfigurationService;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.notification.Notification;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.testagent.service.TestAgentRunService;
import org.eclipse.soda.dk.testagent.service.TestSynchronizationService;
import org.eclipse.soda.dk.testcontroller.service.ControllerLocaterService;
import org.eclipse.soda.dk.testcontroller.service.TestRunListenerService;
import org.eclipse.soda.dk.testmanager.console.TestManagerConsole;
import org.eclipse.soda.dk.testmanager.locater.standard.StandardControllerLocater;
import org.eclipse.soda.dk.testmanager.parser.ContentHandler;
import org.eclipse.soda.dk.testmanager.service.DistributedTestSessionService;
import org.eclipse.soda.dk.testmanager.service.TestManagerService;
import org.eclipse.soda.dk.testmanager.service.TestScriptService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestManager extends ConfigurableObject implements TestManagerService, TestAgentRunService {
	/**
	 * Define message (int) constants.
	 */
	public static final int UNEXPECTED_XML_START = 7150;

	/**
	 * Define the unexpected xml end (int) constant.
	 */
	public static final int UNEXPECTED_XML_END = 7151;

	/**
	 * Define the usage (int) constant.
	 */
	public static final int USAGE = 7152;

	/**
	 * Define the updating with filter (int) constant.
	 */
	public static final int UPDATING_WITH_FILTER = 7153;

	/**
	 * Define the update lc (int) constant.
	 */
	public static final int UPDATE_LC = 7154;

	/**
	 * Define the update uc (int) constant.
	 */
	public static final int UPDATE_UC = 7155;

	/**
	 * Define the sequential lc (int) constant.
	 */
	public static final int SEQUENTIAL_LC = 7156;

	/**
	 * Define the sequential uc (int) constant.
	 */
	public static final int SEQUENTIAL_UC = 7157;

	/**
	 * Define the parallel lc (int) constant.
	 */
	public static final int PARALLEL_LC = 7158;

	/**
	 * Define the parallel uc (int) constant.
	 */
	public static final int PARALLEL_UC = 7159;

	/**
	 * Define the start all tests match (int) constant.
	 */
	public static final int START_ALL_TESTS_MATCH = 7160;

	/**
	 * Define the start single test match (int) constant.
	 */
	public static final int START_SINGLE_TEST_MATCH = 7161;

	/**
	 * Define the invalid filter (int) constant.
	 */
	public static final int INVALID_FILTER = 7162;

	/**
	 * Define the communication error (int) constant.
	 */
	public static final int COMMUNICATION_ERROR = 7163;

	/**
	 * Define the test action (int) constant.
	 */
	public static final int TEST_ACTION = 7164;

	/**
	 * Define the updating config w filter (int) constant.
	 */
	public static final int UPDATING_CONFIG_W_FILTER = 7165;

	/**
	 * Define the creating config (int) constant.
	 */
	public static final int CREATING_CONFIG = 7166;

	/**
	 * Define the create update (int) constant.
	 */
	public static final int CREATE_UPDATE = 7167;

	/**
	 * Define the update create config (int) constant.
	 */
	public static final int UPDATE_CREATE_CONFIG = 7168;

	/**
	 * Define the create update config (int) constant.
	 */
	public static final int CREATE_UPDATE_CONFIG = 7169;

	/**
	 * Define the create lc (int) constant.
	 */
	public static final int CREATE_LC = 7170;

	/**
	 * Define the create uc (int) constant.
	 */
	public static final int CREATE_UC = 7171;

	/**
	 * Define the configuration request (int) constant.
	 */
	public static final int CONFIGURATION_REQUEST = 7172;

	/**
	 * Define the create update one word (int) constant.
	 */
	public static final int CREATE_UPDATE_ONE_WORD = 7173;

	/**
	 * Define the delete lc (int) constant.
	 */
	public static final int DELETE_LC = 7174;

	/**
	 * Define the delete uc (int) constant.
	 */
	public static final int DELETE_UC = 7175;

	/**
	 * Define the test action w dash (int) constant.
	 */
	public static final int TEST_ACTION_W_DASH = 7176;

	/**
	 * Define the deleting configs (int) constant.
	 */
	public static final int DELETING_CONFIGS = 7177;

	/**
	 * Define the errors (int) constant.
	 */
	public static final int ERRORS = 7178;

	/**
	 * Define the script action ended (int) constant.
	 */
	public static final int SCRIPT_ACTION_ENDED = 7179;

	/**
	 * Define the error executing (int) constant.
	 */
	public static final int ERROR_EXECUTING = 7180;

	/**
	 * Define the script action starting (int) constant.
	 */
	public static final int SCRIPT_ACTION_STARTING = 7181;

	/**
	 * Define the config changes (int) constant.
	 */
	public static final int CONFIG_CHANGES = 7182;

	/**
	 * Define the tests (int) constant.
	 */
	public static final int TESTS = 7183;

	/**
	 * Define the test cases (int) constant.
	 */
	public static final int TEST_CASES = 7184;

	/**
	 * Define the test completed (int) constant.
	 */
	public static final int TEST_COMPLETED = 7185;

	/**
	 * Define the error running script (int) constant.
	 */
	public static final int ERROR_RUNNING_SCRIPT = 7186;

	/**
	 * Define the untitled (int) constant.
	 */
	public static final int UNTITLED = 7187;

	/**
	 * Define the invalid match type (int) constant.
	 */
	public static final int INVALID_MATCH_TYPE = 7188;

	/**
	 * Define the action requires filter (int) constant.
	 */
	public static final int ACTION_REQUIRES_FILTER = 7189;

	/**
	 * Define the action requires (int) constant.
	 */
	public static final int ACTION_REQUIRES = 7190;

	/**
	 * Define the test script runner (int) constant.
	 */
	public static final int TEST_SCRIPT_RUNNER = 7191;

	/**
	 * Define the running script (int) constant.
	 */
	public static final int RUNNING_SCRIPT = 7192;

	/**
	 * Define the multiple single expected (int) constant.
	 */
	public static final int MULTIPLE_SINGLE_EXPECTED = 7193;

	/**
	 * Define the cannot process (int) constant.
	 */
	public static final int CANNOT_PROCESS = 7194;

	/**
	 * Define the unexpected attr value (int) field.
	 */
	public static final int UNEXPECTED_ATTR_VALUE = 7195;

	/**
	 * Define the controller class not found (int) constant.
	 */
	public static final int CONTROLLER_CLASS_NOT_FOUND = 7196;

	/**
	 * Define the invalid service identifier (int) constant.
	 */
	public static final int INVALID_SERVICE_IDENTIFIER = 7197;

	/**
	 * Define the local controller not found (int) constant.
	 */
	public static final int LOCAL_CONTROLLER_NOT_FOUND = 7198;

	/**
	 * Define the remote controller not found (int) constant.
	 */
	public static final int REMOTE_CONTROLLER_NOT_FOUND = 7199;

	/**
	 * Define the multiple controllers found (int) constant.
	 */
	public static final int MULTIPLE_CONTROLLERS_FOUND = 7200;

	/**
	 * Define the default resource bundle (ResourceBundle) field.
	 */
	public static ResourceBundle DefaultResourceBundle = Nls.getResourceBundle(TestManagerResourceBundle.class);

	/**
	 * Define the sax parser factory (SAXParserFactory) field.
	 */
	private SAXParserFactory saxParserFactory;

	/**
	 * Define the remote controller locaters (List) field.
	 */
	private List remoteControllerLocaters;

	/**
	 * Define the local controller locater (ControllerLocaterService) field.
	 */
	private ControllerLocaterService localControllerLocater;

	/**
	 * Constructs an instance of this class.
	 */
	public TestManager() {
		super();
		final ConfigurationService defaultConfiguration = EscConfiguration.getConfiguration();
		setConfigurationInformation(defaultConfiguration.getProperties());
		this.remoteControllerLocaters = new Vector();
	}

	/**
	 * Main with the specified arguments parameter.
	 * @param arguments
	 *		The arguments (<code>String[]</code>) parameter.
	 */
	public static void main(final String[] arguments) {
		new TestManager().runMain(arguments);
	}

	/**
	 * Sets the controller locater value.
	 * @param remoteControllerLocater
	 *		The remote controller locater (<code>ControllerLocaterService</code>) parameter.
	 * @see #removeRemoteControllerLocater(ControllerLocaterService)
	 */
	public void addRemoteControllerLocater(final ControllerLocaterService remoteControllerLocater) {
		this.remoteControllerLocaters.add(remoteControllerLocater);
	}

	/**
	 * Create distributed test session with the specified sync service and global run listener parameters and return the DistributedTestSessionService result.
	 * @param syncService
	 *		The sync service (<code>TestSynchronizationService</code>) parameter.
	 * @param globalRunListener
	 *		The global run listener (<code>TestRunListenerService</code>) parameter.
	 * @return Results of the create distributed test session (<code>DistributedTestSessionService</code>) value.
	 */
	public DistributedTestSessionService createDistributedTestSession(final TestSynchronizationService syncService, final TestRunListenerService globalRunListener) {
		return new DistributedTestSession(this.localControllerLocater, this.remoteControllerLocaters, syncService, globalRunListener);
	}

	/**
	 * Gets the default key (String) value.
	 * @return The default key (<code>String</code>) value.
	 */
	public String getDefaultKey() {
		return null;
	}

	/**
	 * Parse with the specified in parameter and return the TestScriptService result.
	 * @param in
	 *		The in (<code>Reader</code>) parameter.
	 * @return Results of the parse (<code>TestScriptService</code>) value.
	 * @throws Exception Exception.
	 */
	public TestScriptService parse(final Reader in) throws Exception {
		SAXParser saxParser;
		if (this.saxParserFactory == null) {
			final SAXParserFactory saxParserFactory = SAXParserFactory.newInstance();
			saxParserFactory.setNamespaceAware(true);
			try {
				saxParserFactory.setValidating(true);
				saxParser = saxParserFactory.newSAXParser();
			} catch (final ParserConfigurationException e) {
				saxParserFactory.setValidating(false);
				saxParser = saxParserFactory.newSAXParser();
			}
		} else {
			saxParser = this.saxParserFactory.newSAXParser();
		}
		return ContentHandler.parse(saxParser, in);
	}

	/**
	 * Remove remote controller locater with the specified remote controller locater parameter.
	 * @param remoteControllerLocater
	 *		The remote controller locater (<code>ControllerLocaterService</code>) parameter.
	 * @see #addRemoteControllerLocater(ControllerLocaterService)
	 */
	public void removeRemoteControllerLocater(final ControllerLocaterService remoteControllerLocater) {
		this.remoteControllerLocaters.remove(remoteControllerLocater);
	}

	/**
	 * Run main with the specified arguments parameter.
	 * @param arguments
	 *		The arguments (<code>String[]</code>) parameter.
	 */
	public void runMain(final String[] arguments) {
		String fileOrUrl;
		if (arguments.length == 0) {
			fileOrUrl = EscObject.getStaticString("testscript", "test.xml"); //$NON-NLS-1$ //$NON-NLS-2$
		} else if (arguments.length == 1) {
			fileOrUrl = arguments[0];
		} else {
			fileOrUrl = null;
			System.err.println(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.USAGE)));
		}
		if (fileOrUrl != null) {
			try {
				Reader in;
				try {
					final URL url = new URL(fileOrUrl);
					in = new InputStreamReader(url.openStream());
				} catch (final MalformedURLException e) {
					in = new FileReader(fileOrUrl);
				}
				final ControllerLocaterService controllerLocater = new StandardControllerLocater();
				addRemoteControllerLocater(controllerLocater);
				final SAXParserFactory saxParserFactory = SAXParserFactory.newInstance();
				saxParserFactory.setNamespaceAware(true);
				setSaxParserFactory(saxParserFactory);
				final TestScriptService testScript = parse(in);
				testScript.getAttributes().put(TestScriptService.ATTR_URL, fileOrUrl);
				final NotificationService notificationService = Notification.getBroker();
				controllerLocater.setNotificationService(notificationService);
				final TestManagerConsole console = new TestManagerConsole();
				final DistributedTestSessionService distributedTestSession = createDistributedTestSession(console, console);
				testScript.run(distributedTestSession, console, false);
				((Notification) notificationService).stop();
			} catch (final Exception e) {
				e.printStackTrace();
			}
		}
	}

	/**
	 * Sets the local controller locater value.
	 * @param localControllerLocater
	 *		The local controller locater (<code>ControllerLocaterService</code>) parameter.
	 */
	public void setLocalControllerLocater(final ControllerLocaterService localControllerLocater) {
		this.localControllerLocater = localControllerLocater;
	}

	/**
	 * Sets the sax parser factory value.
	 * @param saxParserFactory
	 *		The sax parser factory (<code>SAXParserFactory</code>) parameter.
	 */
	public void setSaxParserFactory(final SAXParserFactory saxParserFactory) {
		this.saxParserFactory = saxParserFactory;
	}
}
