package org.eclipse.soda.dk.testmanager;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.HashMap;
import java.util.Map;
import org.eclipse.soda.dk.testmanager.service.TestStatisticsService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestStatistics implements TestStatisticsService {
	/**
	 * Define the statistics (Map) field.
	 */
	private Map statistics;

	/**
	 * Constructs an instance of this class.
	 */
	public TestStatistics() {
		this.statistics = new HashMap();
	}

	/**
	 * Get count with the specified key parameter and return the int result.
	 * @param key
	 *		The key (<code>String</code>) parameter.
	 * @return Results of the get count (<code>int</code>) value.
	 * @see #incrementCount(String,int)
	 */
	public int getCount(final String key) {
		final Integer count = getValue(key);
		return count == null ? 0 : count.intValue();
	}

	/**
	 * Get value with the specified key parameter and return the Integer result.
	 * @param key
	 *		The key (<code>String</code>) parameter.
	 * @return Results of the get value (<code>Integer</code>) value.
	 */
	public synchronized Integer getValue(final String key) {
		return (Integer) this.statistics.get(key);
	}

	/**
	 * Increment count with the specified key and incr parameters.
	 * @param key
	 *		The key (<code>String</code>) parameter.
	 * @param incr
	 *		The incr (<code>int</code>) parameter.
	 * @see #getCount(String)
	 */
	public synchronized void incrementCount(final String key, final int incr) {
		Integer count = getValue(key);
		count = new Integer(count == null ? incr : count.intValue() + incr);
		this.statistics.put(key, count);
	}
}
