package org.eclipse.soda.dk.testmanager.action;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.testmanager.service.TestScriptService;
import org.eclipse.soda.dk.testmanager.service.TestStatisticsService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface Action {
	/**
	 * Add counts with the specified test script parameter.
	 * @param testStatistics
	 *		The test statistics (<code>TestStatisticsService</code>) parameter.
	 */
	public void addCounts(final TestStatisticsService testStatistics);

	/**
	 * Execute with the specified test script parameter.
	 * @param testScript
	 *		The test script (<code>TestScriptService</code>) parameter.
	 * @throws InterruptedException Interrupted Exception.
	 */
	public void execute(final TestScriptService testScript) throws InterruptedException;

	/**
	 * Gets the description (String) value.
	 * @return The description (<code>String</code>) value.
	 */
	public String getDescription();

	/**
	 * Gets the ID (String) value.
	 * @return The id (<code>String</code>) value.
	 */
	public String getId();

	/**
	 * Gets the parent action (Action) value.
	 * @return The parent action (<code>Action</code>) value.
	 * @see #setParentAction(Action)
	 */
	public Action getParentAction();

	/**
	 * Sets the parent action value.
	 * @param parentAction
	 *		The parent action (<code>Action</code>) parameter.
	 * @see #getParentAction()
	 */
	public void setParentAction(final Action parentAction);
}
