package org.eclipse.soda.dk.testmanager.action;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class ConfigurationActionFactory {
	/**
	 * Define the key create (String) constant.
	 */
	public static final String KEY_CREATE = "create"; //$NON-NLS-1$

	/**
	 * Define the key create or update (String) constant.
	 */
	public static final String KEY_CREATE_OR_UPDATE = "createOrUpdate"; //$NON-NLS-1$

	/**
	 * Define the key delete (String) constant.
	 */
	public static final String KEY_DELETE = "delete"; //$NON-NLS-1$

	/**
	 * Define the key update (String) constant.
	 */
	public static final String KEY_UPDATE = "update"; //$NON-NLS-1$

	/**
	 * Constructs an instance of this class.
	 */
	public ConfigurationActionFactory() {
		super();
	}

	/**
	 * Create with the specified id and key parameters and return the ConfigurationAction result.
	 * @param id
	 *		The ID (<code>String</code>) parameter.
	 * @param key
	 *		The key (<code>String</code>) parameter.
	 * @return Results of the create (<code>ConfigurationAction</code>) value.
	 */
	public static ConfigurationAction create(final String id, final String key) {
		if (ConfigurationActionFactory.KEY_CREATE.equals(key)) {
			return new CreateRequest(id);
		}
		if (ConfigurationActionFactory.KEY_CREATE_OR_UPDATE.equals(key)) {
			return new CreateOrUpdateRequest(id);
		}
		if (ConfigurationActionFactory.KEY_DELETE.equals(key)) {
			return new DeleteRequest(id);
		}
		if (ConfigurationActionFactory.KEY_UPDATE.equals(key)) {
			return new UpdateRequest(id);
		}
		return null;
	}
}
