package org.eclipse.soda.dk.testmanager.action;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Dictionary;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class ConfigurationTemplate {
	/**
	 * Define the bundle location (String) field.
	 */
	private String bundleLocation;

	/**
	 * Define the controller id (String) field.
	 */
	private String controllerId;

	/**
	 * Define the factory pid (String) field.
	 */
	private String factoryPid;

	/**
	 * Define the filter (String) field.
	 */
	private String filter;

	/**
	 * Define the pid (String) field.
	 */
	private String pid;

	/**
	 * Define the properties (Dictionary) field.
	 */
	private Dictionary properties;

	/**
	 * Define the id (String) field.
	 */
	private String id;

	/**
	 * Constructs an instance of this class from the specified id, controller id, pid, factory pid, bundle location, filter and properties parameters.
	 * @param id
	 *		The ID (<code>String</code>) parameter.
	 * @param controllerId
	 *		The controller ID (<code>String</code>) parameter.
	 * @param pid
	 *		The PID (<code>String</code>) parameter.
	 * @param factoryPid
	 *		The factory PID (<code>String</code>) parameter.
	 * @param bundleLocation
	 *		The bundle location (<code>String</code>) parameter.
	 * @param filter
	 *		The filter (<code>String</code>) parameter.
	 * @param properties
	 *		The properties (<code>Dictionary</code>) parameter.
	 */
	public ConfigurationTemplate(final String id, final String controllerId, final String pid, final String factoryPid, final String bundleLocation, final String filter, final Dictionary properties) {
		super();
		this.id = id;
		this.controllerId = controllerId;
		this.pid = pid;
		this.factoryPid = factoryPid;
		this.bundleLocation = bundleLocation;
		this.filter = filter;
		this.properties = properties;
	}

	/**
	 * Gets the bundle location (String) value.
	 * @return The bundle location (<code>String</code>) value.
	 */
	public String getBundleLocation() {
		return getProperty(this.bundleLocation);
	}

	/**
	 * Gets the controller ID (String) value.
	 * @return The controller id (<code>String</code>) value.
	 */
	public String getControllerId() {
		return this.controllerId;
	}

	/**
	 * Gets the factory PID (String) value.
	 * @return The factory pid (<code>String</code>) value.
	 */
	public String getFactoryPid() {
		return getProperty(this.factoryPid);
	}

	/**
	 * Gets the filter (String) value.
	 * @return The filter (<code>String</code>) value.
	 */
	public String getFilter() {
		final String pid = getPid();
		if (pid != null) {
			return "(service.pid=" + pid + ')'; //$NON-NLS-1$
		}
		return getProperty(this.filter);
	}

	/**
	 * Gets the ID (String) value.
	 * @return The id (<code>String</code>) value.
	 * @see #getControllerId()
	 */
	public String getId() {
		return this.id;
	}

	/**
	 * Gets the PID (String) value.
	 * @return The pid (<code>String</code>) value.
	 * @see #getFactoryPid()
	 */
	public String getPid() {
		return getProperty(this.pid);
	}

	/**
	 * Gets the properties (Dictionary) value.
	 * @return The properties (<code>Dictionary</code>) value.
	 */
	public Dictionary getProperties() {
		return this.properties;
	}

	/**
	 * Get property with the specified property parameter and return the String result.
	 * @param property
	 *		The property (<code>String</code>) parameter.
	 * @return Results of the get property (<code>String</code>) value.
	 */
	private String getProperty(final String property) {
		if ((property == null) || (property.length() == 0) || property.equalsIgnoreCase("null")) { //$NON-NLS-1$
			return null;
		}
		return property;
	}
}
