package org.eclipse.soda.dk.testmanager.action;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.util.Dictionary;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.testcontroller.service.TestConfigurationService;
import org.eclipse.soda.dk.testcontroller.service.TestSessionService;
import org.eclipse.soda.dk.testmanager.TestManager;
import org.eclipse.soda.dk.testmanager.service.TestScriptService;
import org.osgi.framework.InvalidSyntaxException;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class CreateRequest extends ConfigurationAction {
	/**
	 * Constructs an instance of this class from the specified id parameter.
	 * @param id
	 *		The ID (<code>String</code>) parameter.
	 */
	public CreateRequest(final String id) {
		super(id);
	}

	/**
	 * Execute with the specified test script and template parameters.
	 * @param testScript
	 *		The test script (<code>TestScriptService</code>) parameter.
	 * @param template
	 *		The template (<code>ConfigurationTemplate</code>) parameter.
	 * @throws InvalidSyntaxException Invalid Syntax Exception.
	 * @throws IOException IOException.
	 */
	protected void execute(final TestScriptService testScript, final ConfigurationTemplate template) throws InvalidSyntaxException, IOException {
		final String controllerId = template.getControllerId();
		final String pid = template.getPid();
		final String factoryPid = template.getFactoryPid();
		final String bundleLocation = template.getBundleLocation();
		final Dictionary properties = template.getProperties();
		final TestSessionService testSession = getTestSession(testScript, controllerId);
		if (testSession != null) {
			final TestConfigurationService configurationService = testSession.getTestConfigurationService();
			if (pid != null) {
				final Object[] parms = { pid };
				testScript.getScriptListener().scriptActionInfo(getId(), Nls.format(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.CREATE_UPDATE_CONFIG)), parms));
				configurationService.createOrUpdateConfiguration(pid, bundleLocation, properties);
			} else if (factoryPid != null) {
				final Object[] parms = { factoryPid };
				testScript.getScriptListener().scriptActionInfo(getId(), Nls.format(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.CREATING_CONFIG)), parms));
				configurationService.createFactoryConfiguration(factoryPid, bundleLocation, properties);
			} else {
				handleScriptActionError(testScript, TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.ACTION_REQUIRES)));
			}
		}
	}

	/**
	 * Gets the name (String) value.
	 * @return The name (<code>String</code>) value.
	 */
	protected String getName() {
		return TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.CREATE_UC));
	}
}
