package org.eclipse.soda.dk.testmanager.action;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.util.Dictionary;
import java.util.Iterator;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.testcontroller.service.TestSessionService;
import org.eclipse.soda.dk.testmanager.TestManager;
import org.eclipse.soda.dk.testmanager.service.TestScriptService;
import org.osgi.framework.InvalidSyntaxException;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class SequentialTestAction extends TestAction {
	/**
	 * Constructs an instance of this class from the specified id parameter.
	 * @param id
	 *		The ID (<code>String</code>) parameter.
	 */
	public SequentialTestAction(final String id) {
		super(id);
	}

	/**
	 * Execute with the specified test script parameter.
	 * @param testScript
	 *		The test script (<code>TestScriptService</code>) parameter.
	 * @throws InterruptedException Interrupted Exception.
	 * @see #execute(TestScriptService,TestTemplate)
	 */
	public void execute(final TestScriptService testScript) throws InterruptedException {
		for (final Iterator iterator = getTestTemplatesAndActions().iterator(); iterator.hasNext() && !testScript.getDistributedTestSession().isInterrupted();) {
			executeTemplateOrAction(testScript, iterator.next());
		}
	}

	/**
	 * Execute with the specified test script and template parameters and return the int result.
	 * @param testScript
	 *		The test script (<code>TestScriptService</code>) parameter.
	 * @param template
	 *		The template (<code>TestTemplate</code>) parameter.
	 * @throws InvalidSyntaxException Invalid Syntax Exception.
	 * @throws IOException IOException.
	 * @throws InterruptedException Interrupted Exception.
	 * @see #execute(TestScriptService)
	 */
	protected void execute(final TestScriptService testScript, final TestTemplate template) throws InvalidSyntaxException, IOException, InterruptedException {
		final String controllerId = template.getControllerId();
		final String runId = template.getId();
		final String filter = template.getFilter();
		final String className = template.getClassName();
		final String matchType = template.getMatchType();
		final Dictionary properties = template.getProperties();
		final TestSessionService testSession = getTestSession(testScript, controllerId);
		final TestRunListener runListener = new TestRunListener(testScript.getTestStatistics());
		final String actionId = template.getParentAction().getId();
		if (testSession != null) {
			if ("multiple".equals(matchType)) { //$NON-NLS-1$
				final Object[] parms = { getMatchDescription(filter, className) };
				testScript.getScriptListener().scriptActionInfo(actionId, Nls.format(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.START_ALL_TESTS_MATCH)), parms));
				testSession.runMultipleTests(actionId, runId, filter, className, properties, runListener);
			} else if ((matchType == null) || "single".equals(matchType)) { //$NON-NLS-1$
				final Object[] parms = { getMatchDescription(filter, className) };
				testScript.getScriptListener().scriptActionInfo(actionId, Nls.format(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.START_SINGLE_TEST_MATCH)), parms));
				testSession.runSingleTest(actionId, runId, filter, className, properties, runListener);
			} else {
				final Object[] parms1 = { getDescription() };
				final Object[] parms2 = { matchType };
				testScript.getScriptListener().scriptActionError(actionId, Nls.format(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.INVALID_MATCH_TYPE)), parms1),
						Nls.format(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.MULTIPLE_SINGLE_EXPECTED)), parms2));
			}
		}
	}

	/**
	 * Gets the name (String) value.
	 * @return The name (<code>String</code>) value.
	 */
	protected String getName() {
		return TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.SEQUENTIAL_UC));
	}
}
