package org.eclipse.soda.dk.testmanager.action;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestActionFactory {
	/**
	 * Define the key sequential (String) constant.
	 */
	public static final String KEY_SEQUENTIAL = "sequential"; //$NON-NLS-1$

	/**
	 * Define the key parallel (String) constant.
	 */
	public static final String KEY_PARALLEL = "parallel"; //$NON-NLS-1$

	/**
	 * Constructs an instance of this class.
	 */
	public TestActionFactory() {
		super();
	}

	/**
	 * Create with the specified id and key parameters and return the TestAction result.
	 * @param id
	 *		The ID (<code>String</code>) parameter.
	 * @param key
	 *		The key (<code>String</code>) parameter.
	 * @return Results of the create (<code>TestAction</code>) value.
	 */
	public static TestAction create(final String id, final String key) {
		if ((key == null) || TestActionFactory.KEY_SEQUENTIAL.equals(key)) {
			return new SequentialTestAction(id);
		}
		if (TestActionFactory.KEY_PARALLEL.equals(key)) {
			return new ParallelTestAction(id);
		}
		return null;
	}
}
