package org.eclipse.soda.dk.testmanager.action;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.testcontroller.service.TestRunListenerService;
import org.eclipse.soda.dk.testmanager.service.TestStatisticsService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestRunListener implements TestRunListenerService {
	/**
	 * Define the test statistics (TestStatisticsService) field.
	 */
	private TestStatisticsService testStatistics;

	/**
	 * Constructs an instance of this class from the specified test statistics parameter.
	 * @param testStatistics
	 *		The test statistics (<code>TestStatisticsService</code>) parameter.
	 */
	public TestRunListener(final TestStatisticsService testStatistics) {
		this.testStatistics = testStatistics;
	}

	/**
	 * Test ended with the specified run id and test name parameters.
	 * @param runId
	 *		The run ID (<code>String</code>) parameter.
	 * @param testName
	 *		The test name (<code>String</code>) parameter.
	 * @see #testRunEnded(String)
	 */
	public void testEnded(final String runId, final String testName) {
		/* do nothing */
	}

	/**
	 * Test error with the specified run id, test name and trace parameters.
	 * @param runId
	 *		The run ID (<code>String</code>) parameter.
	 * @param testName
	 *		The test name (<code>String</code>) parameter.
	 * @param trace
	 *		The trace (<code>String</code>) parameter.
	 * @see #testRunError(String,String,String)
	 */
	public void testError(final String runId, final String testName, final String trace) {
		this.testStatistics.incrementCount(TestStatisticsService.STATS_TEST_CASE_ERROR_COUNT, 1);
	}

	/**
	 * Test failed with the specified run id, test name and trace parameters.
	 * @param runId
	 *		The run ID (<code>String</code>) parameter.
	 * @param testName
	 *		The test name (<code>String</code>) parameter.
	 * @param trace
	 *		The trace (<code>String</code>) parameter.
	 */
	public void testFailed(final String runId, final String testName, final String trace) {
		this.testStatistics.incrementCount(TestStatisticsService.STATS_TEST_CASE_FAILED_COUNT, 1);
	}

	/**
	 * Test run ended with the specified run id parameter.
	 * @param runId
	 *		The run ID (<code>String</code>) parameter.
	 */
	public synchronized void testRunEnded(final String runId) {
		/* do nothing */
	}

	/**
	 * Test run error with the specified run id, message and detail parameters.
	 * @param runId
	 *		The run ID (<code>String</code>) parameter.
	 * @param message
	 *		The message (<code>String</code>) parameter.
	 * @param detail
	 *		The detail (<code>String</code>) parameter.
	 */
	public void testRunError(final String runId, final String message, final String detail) {
		/* do nothing */
	}

	/**
	 * Test run started with the specified run id parameter.
	 * @param actionId
	 *		The action ID (<code>String</code>) parameter.
	 * @param runId
	 *		The run ID (<code>String</code>) parameter.
	 */
	public synchronized void testRunStarted(final String actionId, final String runId) {
		/* do nothing */
	}

	/**
	 * Test started with the specified run id and test name parameters.
	 * @param runId
	 *		The run ID (<code>String</code>) parameter.
	 * @param testName
	 *		The test name (<code>String</code>) parameter.
	 * @see #testRunStarted(String,String)
	 */
	public void testStarted(final String runId, final String testName) {
		this.testStatistics.incrementCount(TestStatisticsService.STATS_TEST_CASE_COUNT, 1);
	}
}
