package org.eclipse.soda.dk.testmanager.action;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Dictionary;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class TestTemplate {
	/**
	 * Define the run id (String) field.
	 */
	private String runId;

	/**
	 * Define the controller id (String) field.
	 */
	private String controllerId;

	/**
	 * Define the match (String) field.
	 */
	private String match;

	/**
	 * Define the class name (String) field.
	 */
	private String className;

	/**
	 * Define the filter (String) field.
	 */
	private String filter;

	/**
	 * Define the properties (Dictionary) field.
	 */
	private Dictionary properties;

	/**
	 * Define the parent action (Action) field.
	 */
	private Action parentAction;

	/**
	 * Constructs an instance of this class from the specified run id, filter, class name, match and properties parameters.
	 * @param parentAction
	 *		The parent action (<code>Action</code>) parameter.
	 * @param runId
	 *		The run ID (<code>String</code>) parameter.
	 * @param controllerId
	 *		The controller ID (<code>String</code>) parameter.
	 * @param filter
	 *		The filter (<code>String</code>) parameter.
	 * @param className
	 *		The class name (<code>String</code>) parameter.
	 * @param match
	 *		The match (<code>String</code>) parameter.
	 * @param properties
	 *		The properties (<code>Dictionary</code>) parameter.
	 */
	public TestTemplate(final Action parentAction, final String runId, final String controllerId, final String filter, final String className, final String match, final Dictionary properties) {
		this.parentAction = parentAction;
		this.runId = runId;
		this.controllerId = controllerId;
		this.filter = filter;
		this.className = className;
		this.match = match;
		this.properties = properties;
	}

	/**
	 * Gets the class name (String) value.
	 * @return The class name (<code>String</code>) value.
	 */
	public String getClassName() {
		return getProperty(this.className);
	}

	/**
	 * Gets the controller ID (String) value.
	 * @return The controller id (<code>String</code>) value.
	 */
	public String getControllerId() {
		return this.controllerId;
	}

	/**
	 * Gets the filter (String) value.
	 * @return The filter (<code>String</code>) value.
	 */
	public String getFilter() {
		return getProperty(this.filter);
	}

	/**
	 * Gets the ID (String) value.
	 * @return The id (<code>String</code>) value.
	 * @see #getControllerId()
	 */
	public String getId() {
		return getProperty(this.runId);
	}

	/**
	 * Gets the match type (String) value.
	 * @return The match type (<code>String</code>) value.
	 */
	public String getMatchType() {
		return getProperty(this.match);
	}

	/**
	 * Gets the parent action (Action) value.
	 * @return The parent action (<code>Action</code>) value.
	 */
	Action getParentAction() {
		return this.parentAction;
	}

	/**
	 * Gets the properties (Dictionary) value.
	 * @return The properties (<code>Dictionary</code>) value.
	 */
	public Dictionary getProperties() {
		return this.properties;
	}

	/**
	 * Get property with the specified property parameter and return the String result.
	 * @param property
	 *		The property (<code>String</code>) parameter.
	 * @return Results of the get property (<code>String</code>) value.
	 */
	private String getProperty(final String property) {
		if ((property == null) || (property.length() == 0) || property.equalsIgnoreCase("null")) { //$NON-NLS-1$
			return null;
		}
		return property;
	}
}
