package org.eclipse.soda.dk.testmanager.locater.osgi;

/*************************************************************************
 * Copyright (c) 2008, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.List;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.testcontroller.service.ControllerLocaterService;
import org.eclipse.soda.dk.testcontroller.service.TestControllerService;
import org.eclipse.soda.dk.testmanager.TestManager;
import org.eclipse.soda.sat.core.record.interfaces.IServiceDetecter;
import org.eclipse.soda.sat.core.util.LogUtility;
import org.osgi.framework.InvalidSyntaxException;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class OSGiControllerLocater implements ControllerLocaterService {
	/**
	 * Define the service detecter (IServiceDetecter) field.
	 */
	private IServiceDetecter serviceDetecter;

	/**
	 * Find controller with the specified id parameter and return the TestControllerService result.
	 * @param id
	 *		The ID (<code>String</code>) parameter.
	 * @return Results of the find controller (<code>TestControllerService</code>) value.
	 */
	public TestControllerService findController(final String id) {
		List aquiredControllers = null;
		String filter;
		if (id == null) {
			filter = "(!(type=remote))"; //$NON-NLS-1$
		} else {
			filter = "(id=" + id + ')'; //$NON-NLS-1$
		}
		try {
			int count = 40;
			try {
				do {
					this.serviceDetecter.setFilter(filter);
					aquiredControllers = this.serviceDetecter.getServices();
					if (aquiredControllers.size() == 0) {
						/* Wait 2 sec max for newly created controller to become available (it may never due to exceptions). */
						synchronized (this) {
							wait(500);
						}
					}
				} while ((aquiredControllers.size() == 0) && (count-- > 0));
			} catch (final InterruptedException e) {
				/* No more waiting */
			}
		} catch (final InvalidSyntaxException e) {
			final Object[] parms = { id };
			LogUtility.logError(this, Nls.format(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.INVALID_SERVICE_IDENTIFIER)), parms), e);
			return null;
		}
		if ((aquiredControllers == null) || (aquiredControllers.size() == 0)) {
			if (id == null) {
				LogUtility.logWarning(this, TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.LOCAL_CONTROLLER_NOT_FOUND)));
			} else {
				final Object[] parms = { id };
				LogUtility.logWarning(this, Nls.format(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.REMOTE_CONTROLLER_NOT_FOUND)), parms));
			}
			return null;
		} else if (aquiredControllers.size() > 1) {
			final Object[] parms = { id };
			LogUtility.logWarning(this, Nls.format(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.MULTIPLE_CONTROLLERS_FOUND)), parms));
		}
		return (TestControllerService) aquiredControllers.get(0);
	}

	/**
	 * Sets the notification service value.
	 * @param notificationService
	 *		The notification service (<code>NotificationService</code>) parameter.
	 */
	public void setNotificationService(final NotificationService notificationService) {
		/* do nothing */
	}

	/**
	 * the serviceDetecter to set
	 * @param serviceDetecter
	 *		The service detecter (<code>IServiceDetecter</code>) parameter.
	 */
	public void setServiceDetecter(final IServiceDetecter serviceDetecter) {
		if (this.serviceDetecter != null) {
			this.serviceDetecter.release();
		}
		this.serviceDetecter = serviceDetecter;
		if (serviceDetecter != null) {
			serviceDetecter.acquire();
		}
	}
}
