package org.eclipse.soda.dk.testmanager.locater.standard;

/*************************************************************************
 * Copyright (c) 2008, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.testcontroller.TestController;
import org.eclipse.soda.dk.testcontroller.service.ControllerLocaterService;
import org.eclipse.soda.dk.testcontroller.service.TestControllerService;
import org.eclipse.soda.dk.testmanager.TestManager;
import org.eclipse.soda.sat.core.util.LogUtility;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class StandardControllerLocater implements ControllerLocaterService {
	/**
	 * Define the notification service (NotificationService) field.
	 */
	private NotificationService notificationService;

	/**
	 * Find controller with the specified id parameter and return the TestControllerService result.
	 * @param id
	 *		The ID (<code>String</code>) parameter.
	 * @return Results of the find controller (<code>TestControllerService</code>) value.
	 */
	public TestControllerService findController(final String id) {
		final String className = (id == null) ? TestController.CLASS_NAME : id;
		try {
			final Class controllerClass = Class.forName(className);
			final TestControllerService testController = (TestControllerService) controllerClass.newInstance();
			testController.setNotificationService(this.notificationService);
			return testController;
		} catch (final Exception e) {
			final Object[] parms = { id };
			LogUtility.logWarning(this, Nls.format(TestManager.DefaultResourceBundle.getString(Integer.toString(TestManager.CONTROLLER_CLASS_NOT_FOUND)), parms));
			return null;
		}
	}

	/**
	 * Sets the notification service value.
	 * @param notificationService
	 *		The notification service (<code>NotificationService</code>) parameter.
	 */
	public void setNotificationService(final NotificationService notificationService) {
		this.notificationService = notificationService;
	}
}
