package org.eclipse.soda.dk.testmanager.managed;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.testcontroller.service.ControllerLocaterService;
import org.eclipse.soda.dk.testmanager.service.TestManagerService;
import org.eclipse.soda.sat.core.record.interfaces.IServiceDetecter;
import org.eclipse.soda.sat.core.record.interfaces.ServiceDetecterListener;
import org.eclipse.soda.sat.core.util.FactoryUtility;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class ControllerLocaterDetecter {
	/**
	 * Define the test manager (TestManagerService) field.
	 */
	private TestManagerService testManager;

	/**
	 * Define the detecter (IServiceDetecter) field.
	 */
	private IServiceDetecter detecter;

	/**
	 * Define the detecter listener (ServiceDetecterListener) field.
	 */
	private ServiceDetecterListener detecterListener;

	/**
	 * Constructs an instance of this class from the specified test manager parameter.
	 * @param testManager The test manager (<code>TestManagerService</code>) parameter.
	 */
	public ControllerLocaterDetecter(final TestManagerService testManager) {
		this.testManager = testManager;
	}

	/**
	 * Activate with the specified bundle context parameter.
	 * @param bundleContext The bundle context (<code>BundleContext</code>) parameter.
	 */
	public void activate(final BundleContext bundleContext) {
		FactoryUtility util = FactoryUtility.getInstance();
		this.detecter = util.createServiceDetecter(bundleContext, ControllerLocaterService.SERVICE_NAME);
		this.detecterListener = new ServiceDetecterListener() {
			/**
			 * Service added with the specified detecter, service reference and service parameters.
			 * @param detecter The detecter (<code>IServiceDetecter</code>) parameter.
			 * @param serviceReference The service reference (<code>ServiceReference</code>) parameter.
			 * @param service The service (<code>Object</code>) parameter.
			 */
			public void serviceAdded(final IServiceDetecter detecter, final ServiceReference serviceReference, final Object service) {
				getTestManager().addRemoteControllerLocater((ControllerLocaterService) service);
			}

			/**
			 * Service removed with the specified detecter, service reference and service parameters.
			 * @param detecter The detecter (<code>IServiceDetecter</code>) parameter.
			 * @param serviceReference The service reference (<code>ServiceReference</code>) parameter.
			 * @param service The service (<code>Object</code>) parameter.
			 */
			public void serviceRemoved(final IServiceDetecter detecter, final ServiceReference serviceReference, final Object service) {
				getTestManager().removeRemoteControllerLocater((ControllerLocaterService) service);
			}
		};
		this.detecter.addServiceDetecterListener(this.detecterListener);
		this.detecter.acquire();
	}

	/**
	 * Deactivate.
	 */
	public void deactivate() {
		this.detecter.release();
		this.detecter.removeServiceDetecterListener(this.detecterListener);
		this.detecter = null;
	}

	/**
	 * Gets the test manager (TestManagerService) value.
	 * @return The test manager (<code>TestManagerService</code>) value.
	 */
	protected TestManagerService getTestManager() {
		return this.testManager;
	}
}
