package org.eclipse.soda.dk.testmanager.parser;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.List;
import java.util.StringTokenizer;
import java.util.Vector;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public abstract class AbstractConverter implements PropertyConverter {
	/**
	 * Convert with the specified property parameter and return the Object result.
	 * @param property
	 *		The property (<code>String</code>) parameter.
	 * @return Results of the convert (<code>Object</code>) value.
	 * @see #convert(String,int)
	 */
	public Object convert(final String property) {
		return convert(property, 0);
	}

	/**
	 * Convert with the specified property and cardinality parameters and return the Object result.
	 * @param property
	 *		The property (<code>String</code>) parameter.
	 * @param cardinality
	 *		The cardinality (<code>int</code>) parameter.
	 * @return Results of the convert (<code>Object</code>) value.
	 * @see #convert(String)
	 */
	public Object convert(final String property, final int cardinality) {
		if (cardinality == 0) {
			return doConversion(property);
		}
		if (cardinality < 0) {
			final StringTokenizer tokenizer = new StringTokenizer(property, ","); //$NON-NLS-1$
			final List list = new Vector(tokenizer.countTokens());
			while (tokenizer.hasMoreTokens()) {
				list.add(doConversion(tokenizer.nextToken()));
			}
			return list;
		}
		final StringTokenizer tokenizer = new StringTokenizer(property, ","); //$NON-NLS-1$
		return doPrimitiveArrayConversion(tokenizer);
	}

	/**
	 * Create array with the specified size parameter and return the Object[] result.
	 * @param size
	 *		The size (<code>int</code>) parameter.
	 * @return Results of the create array (<code>Object[]</code>) value.
	 */
	protected abstract Object[] createArray(final int size);

	/**
	 * Do conversion with the specified property parameter and return the Object result.
	 * @param property
	 *		The property (<code>String</code>) parameter.
	 * @return Results of the do conversion (<code>Object</code>) value.
	 * @see #doPrimitiveArrayConversion(StringTokenizer)
	 */
	protected abstract Object doConversion(final String property);

	/**
	 * Do primitive array conversion with the specified tokenizer parameter and return the Object result.
	 * @param tokenizer
	 *		The tokenizer (<code>StringTokenizer</code>) parameter.
	 * @return Results of the do primitive array conversion (<code>Object</code>) value.
	 */
	protected abstract Object doPrimitiveArrayConversion(final StringTokenizer tokenizer);
}
