package org.eclipse.soda.dk.testmanager.parser;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.StringTokenizer;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class IntegerConverter extends AbstractConverter {
	/**
	 * Create array with the specified size parameter and return the Object[] result.
	 * @param size
	 *		The size (<code>int</code>) parameter.
	 * @return Results of the create array (<code>Object[]</code>) value.
	 */
	protected Object[] createArray(final int size) {
		return new Integer[size];
	}

	/**
	 * Do conversion with the specified property parameter and return the Object result.
	 * @param property
	 *		The property (<code>String</code>) parameter.
	 * @return Results of the do conversion (<code>Object</code>) value.
	 * @see #doPrimitiveArrayConversion(StringTokenizer)
	 */
	protected Object doConversion(final String property) {
		return Integer.valueOf(property);
	}

	/**
	 * Do primitive array conversion with the specified tokenizer parameter and return the Object result.
	 * @param tokenizer
	 *		The tokenizer (<code>StringTokenizer</code>) parameter.
	 * @return Results of the do primitive array conversion (<code>Object</code>) value.
	 */
	protected Object doPrimitiveArrayConversion(final StringTokenizer tokenizer) {
		final int[] result = new int[tokenizer.countTokens()];
		for (int i = 0; i < result.length; i++) {
			result[i] = Integer.parseInt(tokenizer.nextToken());
		}
		return result;
	}
}
