package org.eclipse.soda.dk.testmanager.service;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface ScriptRunListenerService {
	/**
	 * Script action ended with the specified message parameter.
	 * @param actionId
	 *		The action ID (<code>String</code>) parameter.
	 * @param message
	 *		The message (<code>String</code>) parameter.
	 */
	public void scriptActionEnded(final String actionId, final String message);

	/**
	 * Script action error with the specified message and detail parameters.
	 * @param actionId
	 *		The action ID (<code>String</code>) parameter.
	 * @param message
	 *		The message (<code>String</code>) parameter.
	 * @param detail
	 *		The detail (<code>String</code>) parameter.
	 */
	public void scriptActionError(final String actionId, final String message, final String detail);

	/**
	 * Script action info with the specified message parameter.
	 * @param actionId
	 *		The action ID (<code>String</code>) parameter.
	 * @param message
	 *		The message (<code>String</code>) parameter.
	 */
	public void scriptActionInfo(final String actionId, final String message);

	/**
	 * Script action started with the specified message parameter.
	 * @param parentActionId
	 *		The parent action ID (<code>String</code>) parameter.
	 * @param actionId
	 *		The action ID (<code>String</code>) parameter.
	 * @param message
	 *		The message (<code>String</code>) parameter.
	 */
	public void scriptActionStarted(final String parentActionId, final String actionId, final String message);

	/**
	 * Script run ended with the specified test statistics parameter.
	 * @param testStatistics
	 *		The test statistics (<code>TestStatisticsService</code>) parameter.
	 */
	public void scriptRunEnded(final TestStatisticsService testStatistics);

	/**
	 * Script run error with the specified message and trace parameters.
	 * @param message
	 *		The message (<code>String</code>) parameter.
	 * @param trace
	 *		The trace (<code>String</code>) parameter.
	 */
	public void scriptRunError(final String message, final String trace);

	/**
	 * Script run started with the specified script parameter.
	 * @param script
	 *		The script (<code>TestScriptService</code>) parameter.
	 */
	public void scriptRunStarted(final TestScriptService script);
}
