package org.eclipse.soda.dk.testmanager.service;

/*************************************************************************
 * Copyright (c) 2006, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.Reader;
import javax.xml.parsers.SAXParserFactory;
import org.eclipse.soda.dk.testagent.service.TestSynchronizationService;
import org.eclipse.soda.dk.testcontroller.service.ControllerLocaterService;
import org.eclipse.soda.dk.testcontroller.service.TestRunListenerService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface TestManagerService {
	/**
	 * Define the service name (String) constant.
	 */
	public static final String SERVICE_NAME = TestManagerService.class.getName();

	/**
	 * Add remote controller locater with the specified remote controller locater parameter.
	 * @param remoteControllerLocater
	 *		The remote controller locater (<code>ControllerLocaterService</code>) parameter.
	 * @see #removeRemoteControllerLocater(ControllerLocaterService)
	 */
	public void addRemoteControllerLocater(final ControllerLocaterService remoteControllerLocater);

	/**
	 * Create distributed test session with the specified sync service and global run listener parameters and return the DistributedTestSessionService result.
	 * @param syncService
	 *		The sync service (<code>TestSynchronizationService</code>) parameter.
	 * @param globalRunListener
	 *		The global run listener (<code>TestRunListenerService</code>) parameter.
	 * @return Results of the create distributed test session (<code>DistributedTestSessionService</code>) value.
	 */
	public DistributedTestSessionService createDistributedTestSession(final TestSynchronizationService syncService, final TestRunListenerService globalRunListener);

	/**
	 * Parse with the specified in parameter and return the TestScriptService result.
	 * @param in
	 *		The in (<code>Reader</code>) parameter.
	 * @return Results of the parse (<code>TestScriptService</code>) value.
	 * @throws Exception Exception.
	 */
	public TestScriptService parse(final Reader in) throws Exception;

	/**
	 * Remove remote controller locater with the specified remote controller locater parameter.
	 * @param remoteControllerLocater
	 *		The remote controller locater (<code>ControllerLocaterService</code>) parameter.
	 * @see #addRemoteControllerLocater(ControllerLocaterService)
	 */
	public void removeRemoteControllerLocater(final ControllerLocaterService remoteControllerLocater);

	/**
	 * Sets the local controller locater value.
	 * @param localControllerLocater
	 *		The local controller locater (<code>ControllerLocaterService</code>) parameter.
	 */
	public void setLocalControllerLocater(final ControllerLocaterService localControllerLocater);

	/**
	 * the saxParserFactory to set
	 * @param saxParserFactory
	 *		The sax parser factory (<code>SAXParserFactory</code>) parameter.
	 */
	public void setSaxParserFactory(final SAXParserFactory saxParserFactory);
}
