package org.eclipse.soda.dk.testmanager.service;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.util.Map;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface TestScriptService {
	/**
	 * Define the attr title (String) constant.
	 */
	public final static String ATTR_TITLE = "title"; //$NON-NLS-1$

	/**
	 * Define the attr provider (String) constant
	 */
	public final static String ATTR_PROVIDER = "provider"; //$NON-NLS-1$

	/**
	 * Define the attr version (String) constant.
	 */
	public final static String ATTR_VERSION = "version"; //$NON-NLS-1$

	/**
	 * Define the attr vendor (String) constant.
	 */
	public final static String ATTR_VENDOR = "vendor"; //$NON-NLS-1$

	/**
	 * Define the attr description (String) constant.
	 */
	public final static String ATTR_DESCRIPTION = "description"; //$NON-NLS-1$

	/**
	 * Define the attr url (String) constant.
	 */
	public final static String ATTR_URL = "url"; //$NON-NLS-1$

	/**
	 * Gets the attributes (Map) value.
	 * @return The attributes (<code>Map</code>) value.
	 */
	public Map getAttributes();

	/**
	 * Gets the distributed test session (DistributedTestSessionService) value.
	 * @return The distributed test session (<code>DistributedTestSessionService</code>) value.
	 */
	public DistributedTestSessionService getDistributedTestSession();

	/**
	 * Gets the script listener (ScriptRunListenerService) value.
	 * @return the scriptListener
	 */
	public ScriptRunListenerService getScriptListener();

	/**
	 * Gets the test statistics (TestStatisticsService) value.
	 * @return the testStatistics
	 */
	public TestStatisticsService getTestStatistics();

	/**
	 * Run with the specified test session, script listener and asynchronous parameters.
	 * @param distributedTestSession
	 *		The distributed test session (<code>DistributedTestSessionService</code>) parameter.
	 * @param scriptListener
	 *		The script listener (<code>ScriptRunListenerService</code>) parameter.
	 * @param asynchronous
	 *		The asynchronous (<code>boolean</code>) parameter.
	 * @throws InterruptedException Interrupted Exception.
	 * @throws IOException IOException.
	 */
	public void run(final DistributedTestSessionService distributedTestSession, final ScriptRunListenerService scriptListener, final boolean asynchronous) throws InterruptedException, IOException;
}
