package org.eclipse.soda.dk.testmanager.servlet;

/*************************************************************************
 * Copyright (c) 2005, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.io.InputStream;
import java.util.ResourceBundle;
import javax.servlet.Servlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.eclipse.soda.dk.device.servlet.DeviceServlet;
import org.eclipse.soda.dk.device.servlet.DeviceServletContext;
import org.eclipse.soda.dk.device.servlet.service.DeviceServletService;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.testmanager.service.TestManagerService;
import org.eclipse.soda.dk.testmanager.service.TestScriptService;
import org.eclipse.soda.dk.testmanager.service.DistributedTestSessionService;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class DeviceTestManagerServlet extends DeviceServlet implements DeviceServletService, Servlet {
	/**
	 * Define the serial version uid (long) constant.
	 */
	private static final long serialVersionUID = -6781984721787178138L;

	/**
	 * Define the stream closed (int) constant.
	 */
	public static final int STREAM_CLOSED = 7250;

	/**
	 * Define the invalid header (int) constant.
	 */
	public static final int INVALID_HEADER = 7251;

	/**
	 * Define the failed to run script (int) constant.
	 */
	public static final int FAILED_TO_RUN_SCRIPT = 7252;

	/**
	 * Define the expected encoding (int) constant.
	 */
	public static final int EXPECTED_ENCODING = 7253;

	/**
	 * Define the received encoding (int) constant.
	 */
	public static final int RECEIVED_ENCODING = 7254;

	/**
	 * Define the ending script action (int) constant.
	 */
	public static final int ENDING_SCRIPT_ACTION = 7256;

	/**
	 * Define the error executing action (int) constant.
	 */
	public static final int ERROR_EXECUTING_ACTION = 7257;

	/**
	 * Define the starting script action (int) constant.
	 */
	public static final int STARTING_SCRIPT_ACTION = 7258;

	/**
	 * Define the config changes (int) constant.
	 */
	public static final int CONFIG_CHANGES = 7259;

	/**
	 * Define the tests (int) constant.
	 */
	public static final int TESTS = 7260;

	/**
	 * Define the test cases (int) constant.
	 */
	public static final int TEST_CASES = 7261;

	/**
	 * Define the test completed (int) constant.
	 */
	public static final int TEST_COMPLETED = 7262;

	/**
	 * Define the error running script (int) constant.
	 */
	public static final int ERROR_RUNNING_SCRIPT = 7263;

	/**
	 * Define the untitled (int) constant.
	 */
	public static final int UNTITLED = 7264;

	/**
	 * Define the running test script (int) constant.
	 */
	public static final int RUNNING_TEST_SCRIPT = 7265;

	/**
	 * Define the error in test (int) constant.
	 */
	public static final int ERROR_IN_TEST = 7266;

	/**
	 * Define the test failed (int) constant.
	 */
	public static final int TEST_FAILED = 7267;

	/**
	 * Define the error in test run (int) constant.
	 */
	public static final int ERROR_IN_TEST_RUN = 7268;

	/**
	 * Define the running (int) constant.
	 */
	public static final int RUNNING = 7269;

	/**
	 * Define the default resource bundle (ResourceBundle) field.
	 */
	public static ResourceBundle DefaultResourceBundle = Nls.getResourceBundle(DeviceTestManagerServletResourceBundle.class);

	/**
	 * Define the test manager (TestManagerService) field.
	 */
	private TestManagerService testManager;

	/**
	 * Constructs an instance of this class.
	 */
	public DeviceTestManagerServlet() {
		super();
	}

	/**
	 * Replace all with the specified str, find and replace parameters and return the String result.
	 * @param str	The str (<code>String</code>) parameter.
	 * @param find	The find (<code>String</code>) parameter.
	 * @param replace	The replace (<code>String</code>) parameter.
	 * @return	Results of the replace all (<code>String</code>) value.
	 */
	private static String replaceAll(final String str, final String find, final String replace) {
		int pos = 0, lastpos = 0;
		int len = find.length();
		StringBuffer b = new StringBuffer();
		while ((pos = str.indexOf(find, pos)) >= 0) {
			b.append(str.substring(lastpos, pos));
			b.append(replace);
			pos += len;
			lastpos = pos;
		}
		b.append(str.substring(lastpos));
		return b.toString();
	}

	/**
	 * Create context with the specified request and response parameters and return the DeviceServletContext result.
	 * @param request	The request (<code>HttpServletRequest</code>) parameter.
	 * @param response	The response (<code>HttpServletResponse</code>) parameter.
	 * @return Results of the create context (<code>DeviceServletContext</code>)
	 * value.
	 */
	public DeviceServletContext createContext(final HttpServletRequest request, final HttpServletResponse response) {
		final DeviceTestManagerServletContext context = new DeviceTestManagerServletContext(request, response, getServletAlias());
		return context;
	}

	/**
	 * Handle abort action with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void handleAbortAction(final DeviceServletContext context) {
		HttpSession session = context.getRequest().getSession();
		/* Must use deprecated getValue for Servlet 2.1 spec. */
		TestControl testControl = (TestControl) session.getValue(TestControl.class.getName());
		if (testControl != null) {
			testControl.finished();
		}
		context.template("ok"); //$NON-NLS-1$
	}

	/**
	 * Handle cancel action with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void handleCancelAction(final DeviceServletContext context) {
		HttpSession session = context.getRequest().getSession();
		/* Must use deprecated getValue for Servlet 2.1 spec. */
		TestControl testControl = (TestControl) session.getValue(TestControl.class.getName());
		if (testControl != null) {
			testControl.confirmRequest(false);
		}
		context.template("ok"); //$NON-NLS-1$
	}

	/**
	 * Handle confirm action with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void handleConfirmAction(final DeviceServletContext context) {
		HttpSession session = context.getRequest().getSession();
		/* Must use deprecated getValue for Servlet 2.1 spec. */
		TestControl testControl = (TestControl) session.getValue(TestControl.class.getName());
		if (testControl != null) {
			testControl.confirmRequest(true);
		}
		context.template("ok"); //$NON-NLS-1$
	}

	/**
	 * Handle next request action with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void handleNextRequestAction(final DeviceServletContext context) {
		HttpSession session = context.getRequest().getSession();
		/* Must use deprecated getValue for Servlet 2.1 spec. */
		TestControl testControl = (TestControl) session.getValue(TestControl.class.getName());
		if (testControl != null) {
			try {
				TestControl.Request request = testControl.waitForNextEvent();
				if (request != null) {
					context.addEntity("Prompt", escape(request.prompt)); //$NON-NLS-1$
					context.addEntity("TestName", escape(request.testName)); //$NON-NLS-1$
					context.template("requestspec"); //$NON-NLS-1$
				} else {
					/* Signal end of test. */
					sendHttpError(context, HttpServletResponse.SC_RESET_CONTENT);
				}
			} catch (InterruptedException e) {
				/* Signal end of test. */
				sendHttpError(context, HttpServletResponse.SC_RESET_CONTENT);
			}
		} else {
			sendHttpError(context, HttpServletResponse.SC_BAD_REQUEST);
		}
	}

	/**
	 * Handle run action with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void handleRunAction(final DeviceServletContext context) {
		MimeMultiPart parser = new MimeMultiPart(context.getRequest(), context.getResponse());
		if ("multipart/form-data".equalsIgnoreCase(parser.getContentType())) { //$NON-NLS-1$)
			try {
				MimePart part;
				while ((part = parser.getNextPart()) != null) {
					TestScriptService testScript = this.testManager.parse(part.getReader());
					String header = part.getHeader("content-disposition"); //$NON-NLS-1$
					if (header != null) {
						HeaderValue contentDisposition = new HeaderValue(header);
						String fileName = contentDisposition.getAttribute("filename"); //$NON-NLS-1$
						testScript.getAttributes().put(TestScriptService.ATTR_URL, fileName);
					}
					TestControl testControl = new TestControl();
					HttpSession session = context.getRequest().getSession();
					/* Must use deprecated putValue for Servlet 2.1 spec. */
					session.putValue(TestControl.class.getName(), testControl);
					TestReport testReport = new TestReport();
					DistributedTestSessionService distributedTestSession = this.testManager.createDistributedTestSession(testControl, testReport);
					testControl.setTestSessionManager(distributedTestSession);
					/* Must use deprecated putValue for Servlet 2.1 spec. */
					session.putValue(TestReport.class.getName(), testReport);
					testScript.run(distributedTestSession, testReport, true);
					context.template("testframeset"); //$NON-NLS-1$
				}
			} catch (Exception e) {
				sendErrorPage(context, DeviceTestManagerServlet.DefaultResourceBundle.getString(Integer.toString(DeviceTestManagerServlet.FAILED_TO_RUN_SCRIPT)), e.toString());
			}
		} else {
			Object[] parms = { parser.getContentType() };
			sendErrorPage(context, DeviceTestManagerServlet.DefaultResourceBundle.getString(Integer.toString(DeviceTestManagerServlet.EXPECTED_ENCODING)), Nls.format(DeviceTestManagerServlet.DefaultResourceBundle.getString(Integer
					.toString(DeviceTestManagerServlet.RECEIVED_ENCODING)), parms));
		}
		try {
			/* Must flush to avoid unparsed data to be interpreted as next request. */
			InputStream in = context.getRequest().getInputStream();
			byte data[] = new byte[1024];
			while (in.available() > 0) {
				in.read(data);
			}
		} catch (IOException e) {
			/* Ignore */
		}
	}

	/**
	 * Process action with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void processAction(final DeviceServletContext context) {
		String action = context.getRequest().getParameter("action"); //$NON-NLS-1$
		if (action == null) {
			sendSelectionPage(context);
		} else if ("run".equals(action)) { //$NON-NLS-1$
			handleRunAction(context);
		} else if ("abort".equals(action)) { //$NON-NLS-1$
			handleAbortAction(context);
		} else if ("confirm".equals(action)) { //$NON-NLS-1$
			handleConfirmAction(context);
		} else if ("cancel".equals(action)) { //$NON-NLS-1$
			handleCancelAction(context);
		} else if ("nextrequest".equals(action)) { //$NON-NLS-1$
			handleNextRequestAction(context);
		} else {
			/* For no or unknown action return bad request. */
			sendHttpError(context, HttpServletResponse.SC_BAD_REQUEST);
		}
	}

	/**
	 * Process bottom frame with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void processBottomFrame(final DeviceServletContext context) {
		context.template("framebegin"); //$NON-NLS-1$
		context.template("end"); //$NON-NLS-1$
	}

	/**
	 * Process control frame with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void processControlFrame(final DeviceServletContext context) {
		context.template("framebegin"); //$NON-NLS-1$
		context.template("controlframe"); //$NON-NLS-1$
		context.template("frameend"); //$NON-NLS-1$
	}

	/**
	 * Process log frame with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void processLogFrame(final DeviceServletContext context) {
		context.getResponse().setHeader("pragma", "no-cache"); //$NON-NLS-1$ //$NON-NLS-2$
		context.template("framebegin"); //$NON-NLS-1$
		context.template("logbegin"); //$NON-NLS-1$
		HttpSession session = context.getRequest().getSession();
		/* Must use deprecated getValue for Servlet 2.1 spec. */
		TestReport testReport = (TestReport) session.getValue(TestReport.class.getName());
		if (testReport != null) {
			TestReport.Event event;
			try {
				while ((event = testReport.waitForNextEvent()) != null) {
					final Object timestamp = Nls.formatTimestamp(event.timestamp.getTime());
					context.addEntity("Timestamp", timestamp); //$NON-NLS-1$
					context.addEntity("Message", escape(event.message)); //$NON-NLS-1$
					context.addEntity("Class", event.error ? "error" : "normal"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$  
					if (event.detail != null) {
						String htmlDetail = replaceAll(escape(event.detail), "\n", "<br>\n"); //$NON-NLS-1$ //$NON-NLS-2$
						context.addEntity("Detail", htmlDetail); //$NON-NLS-1$
						context.template("logdetail"); //$NON-NLS-1$
					} else {
						context.template("logline"); //$NON-NLS-1$
					}
					context.getResponse().getWriter().flush();
				}
				/* Must use deprecated getValue for Servlet 2.1 spec. */
				TestControl testControl = (TestControl) session.getValue(TestControl.class.getName());
				if (testControl != null) {
					testControl.finished();
				}
			} catch (IOException e) {
				/* Ignore */
			} catch (InterruptedException e) {
				/* Ignore */
			}
		}
		context.template("logend"); //$NON-NLS-1$
		context.template("frameend"); //$NON-NLS-1$
	}

	/**
	 * Process request with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	public void processRequest(final DeviceServletContext context) {
		if (context.getPath().length() > 0) {
			/* Ignore unsupported request paths, like /stylesheet.css */
			sendHttpError(context, HttpServletResponse.SC_NOT_FOUND);
			return;
		}
		String frame = context.getRequest().getParameter("frame"); //$NON-NLS-1$
		if (frame == null) {
			processAction(context);
		} else if (frame.equals("top")) { //$NON-NLS-1$
			processTopFrame(context);
		} else if (frame.equals("bottom")) { //$NON-NLS-1$
			processBottomFrame(context);
		} else if (frame.equals("control")) { //$NON-NLS-1$
			processControlFrame(context);
		} else if (frame.equals("log")) { //$NON-NLS-1$
			processLogFrame(context);
		} else {
			/* For no or unknown frame return bad request. */
			sendHttpError(context, HttpServletResponse.SC_BAD_REQUEST);
		}
	}

	/**
	 * Process top frame with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void processTopFrame(final DeviceServletContext context) {
		context.template("begin"); //$NON-NLS-1$
		context.template("frameend"); //$NON-NLS-1$
	}

	/**
	 * Send error page with the specified context, error message and error detail parameters.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 * @param errorMessage	The error message (<code>String</code>) parameter.
	 * @param errorDetail	The error detail (<code>String</code>) parameter.
	 */
	private void sendErrorPage(final DeviceServletContext context, final String errorMessage, final String errorDetail) {
		context.template("begin"); //$NON-NLS-1$
		context.template("warning"); //$NON-NLS-1$
		context.addEntity("ErrorMessage", escape(errorMessage)); //$NON-NLS-1$
		context.addEntity("ErrorDetail", escape(errorDetail)); //$NON-NLS-1$
		context.template("error"); //$NON-NLS-1$
		context.template("end"); //$NON-NLS-1$
	}

	/**
	 * Send http error with the specified context and error code parameters.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 * @param errorCode	The error code (<code>int</code>) parameter.
	 */
	private void sendHttpError(final DeviceServletContext context, final int errorCode) {
		try {
			context.getResponse().sendError(errorCode);
		} catch (final IOException e) {
			/* ignore exception */
		}
	}

	/**
	 * Send selection page with the specified context parameter.
	 * @param context	The context (<code>DeviceServletContext</code>) parameter.
	 */
	private void sendSelectionPage(final DeviceServletContext context) {
		context.template("begin"); //$NON-NLS-1$
		context.template("warning"); //$NON-NLS-1$
		context.template("testselectionform"); //$NON-NLS-1$
		context.template("end"); //$NON-NLS-1$
	}

	/**
	 * Sets the test manager value.
	 * @param testManager	The test manager (<code>TestManagerService</code>) parameter.
	 */
	public void setTestManager(final TestManagerService testManager) {
		this.testManager = testManager;
	}
}
