package org.eclipse.soda.dk.testmanager.servlet;

/*************************************************************************
 * Copyright (c) 2006, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class HeaderValue {
	/**
	 * Define the value (String) field.
	 */
	private String value;

	/**
	 * Define the attributes (Map) field.
	 */
	private Map attributes;

	/**
	 * Constructs an instance of this class from the specified value with attributes parameter.
	 * @param valueWithAttributes	The value with attributes (<code>String</code>) parameter.
	 */
	public HeaderValue(final String valueWithAttributes) {
		StringTokenizer tokenizer = new StringTokenizer(valueWithAttributes, ";"); //$NON-NLS-1$
		this.value = tokenizer.nextToken().trim();
		this.attributes = new HashMap();
		while (tokenizer.hasMoreElements()) {
			String token = tokenizer.nextToken();
			int pos = token.indexOf('=');
			if (pos > 0) {
				String attrKey = token.substring(0, pos).trim().toLowerCase();
				String attrValue = token.substring(pos + 1).trim();
				if (attrValue.startsWith("\"") && attrValue.endsWith("\"")) { //$NON-NLS-1$ //$NON-NLS-2$
					attrValue = attrValue.substring(1, attrValue.length() - 1);
				}
				this.attributes.put(attrKey, attrValue);
			}
		}
	}

	/**
	 * Get attribute with the specified key parameter and return the String result.
	 * @param key	The key (<code>String</code>) parameter.
	 * @return	Results of the get attribute (<code>String</code>) value.
	 */
	public String getAttribute(final String key) {
		return (String) this.attributes.get(key);
	}

	/**
	 * Gets the attributes (Map) value.
	 * @return the attributes
	 */
	public Map getAttributes() {
		return this.attributes;
	}

	/**
	 * Gets the value (String) value.
	 * @return the value
	 * @see #HeaderValue(String)
	 */
	public String getValue() {
		return this.value;
	}
}
