package org.eclipse.soda.dk.testmanager.servlet;

/*************************************************************************
 * Copyright (c) 2006, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.UnsupportedEncodingException;
import java.util.Hashtable;
import java.util.Map;
import org.eclipse.soda.dk.nls.Nls;
import org.eclipse.soda.dk.testmanager.servlet.MimeMultiPart.PartInputStream;

/**
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class MimePart {
	/**
	 * Define the in (PartInputStream) field.
	 */
	private PartInputStream in;

	/**
	 * Define the headers (Map) field.
	 */
	private Map headers;

	/**
	 * Constructs an instance of this class from the specified parser parameter.
	 * @param in	The in (<code>PartInputStream</code>) parameter.
	 * @throws IOException IOException.
	 */
	public MimePart(final MimeMultiPart.PartInputStream in) throws IOException {
		this.in = in;
		this.headers = new Hashtable();
		parseHeaders();
	}

	/**
	 * Get header with the specified key parameter and return the String result.
	 * @param key	The key (<code>String</code>) parameter.
	 * @return	Results of the get header (<code>String</code>) value.
	 */
	public String getHeader(final String key) {
		return (String) this.headers.get(key);
	}

	/**
	 * Gets the headers (Map) value.
	 * @return the headers
	 * @see #parseHeaders()
	 */
	public Map getHeaders() {
		return this.headers;
	}

	/**
	 * Gets the input stream value.
	 * @return	The input stream (<code>InputStream</code>) value.
	 */
	public InputStream getInputStream() {
		return this.in;
	}

	/**
	 * Gets the reader value.
	 * @return the reader
	 * @throws UnsupportedEncodingException Unsupported Encoding Exception.
	 */
	public Reader getReader() throws UnsupportedEncodingException {
		String characterEncoding = this.in.getCharacterEncoding();
		if (characterEncoding == null) {
			return new InputStreamReader(this.in);
		}
		return new InputStreamReader(this.in, characterEncoding);
	}

	/**
	 * Parse headers.
	 * @throws IOException IOException.
	 * @see #getHeaders()
	 */
	protected void parseHeaders() throws IOException {
		boolean firstLine = true;
		String header = null;
		StringBuffer value = new StringBuffer(256);
		while (true) {
			String line = this.in.readLine();
			if (line == null || line.length() == 0) {
				if (!firstLine) {
					this.headers.put(header, value.toString().trim());
				}
				break;
			}
			char c = line.charAt(0);
			if ((c == ' ') || (c == '\t')) {
				if (firstLine) {
					Object[] parms = { new Integer(line) };
					throw new IOException(Nls.format(DeviceTestManagerServlet.DefaultResourceBundle.getString(Integer.toString(DeviceTestManagerServlet.INVALID_HEADER)), parms));
				}
				value.append(line.substring(1));
				continue;
			}
			if (!firstLine) {
				this.headers.put(header, value.toString().trim());
				value.setLength(0);
			}
			int colon = line.indexOf(':', 0);
			header = line.substring(0, colon).toLowerCase();
			value.append(line.substring(colon + 1));
			firstLine = false;
		}
	}
}
